<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'baxo: persoña, persoña, carnaxon ciæa e carnaxon assæ ciæa',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'baxo: persoña, persoña, carnaxon ciæa e carnaxon cô d’öiva',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'baxo: persoña, persoña, carnaxon ciæa e carnaxon assæ scua',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'baxo: persoña, persoña, carnaxon ciæa e carnaxon scua',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'baxo: persoña, persoña, carnaxon assæ ciæa e carnaxon ciæa',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'baxo: persoña, persoña, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'baxo: persoña, persoña, carnaxon assæ ciæa e carnaxon assæ scua',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'baxo: persoña, persoña, carnaxon assæ ciæa e carnaxon scua',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'baxo: persoña, persoña, carnaxon cô d’öiva e carnaxon ciæa',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'baxo: persoña, persoña, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'baxo: persoña, persoña, carnaxon cô d’öiva e carnaxon assæ scua',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'baxo: persoña, persoña, carnaxon cô d’öiva e carnaxon scua',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'baxo: persoña, persoña, carnaxon assæ scua e carnaxon ciæa',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'baxo: persoña, persoña, carnaxon assæ scua e carnaxon assæ ciæa',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'baxo: persoña, persoña, carnaxon assæ scua e carnaxon cô d’öiva',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'baxo: persoña, persoña, carnaxon assæ scua e carnaxon scua',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'baxo: persoña, persoña, carnaxon scua e carnaxon ciæa',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'baxo: persoña, persoña, carnaxon scua e carnaxon assæ ciæa',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'baxo: persoña, persoña, carnaxon scua e carnaxon cô d’öiva',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'baxo: persoña, persoña, carnaxon scua e carnaxon assæ scua',
    '👨🏻‍❤‍💋‍👨🏻' => 'baxo: òmmo, òmmo e carnaxon ciæa',
    '👨🏻‍❤‍💋‍👨🏼' => 'baxo: òmmo, òmmo, carnaxon ciæa e carnaxon assæ ciæa',
    '👨🏻‍❤‍💋‍👨🏽' => 'baxo: òmmo, òmmo, carnaxon ciæa e carnaxon cô d’öiva',
    '👨🏻‍❤‍💋‍👨🏾' => 'baxo: òmmo, òmmo, carnaxon ciæa e carnaxon assæ scua',
    '👨🏻‍❤‍💋‍👨🏿' => 'baxo: òmmo, òmmo, carnaxon ciæa e carnaxon scua',
    '👨🏼‍❤‍💋‍👨🏻' => 'baxo: òmmo, òmmo, carnaxon assæ ciæa e carnaxon ciæa',
    '👨🏼‍❤‍💋‍👨🏼' => 'baxo: òmmo, òmmo e carnaxon assæ ciæa',
    '👨🏼‍❤‍💋‍👨🏽' => 'baxo: òmmo, òmmo, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👨🏼‍❤‍💋‍👨🏾' => 'baxo: òmmo, òmmo, carnaxon assæ ciæa e carnaxon assæ scua',
    '👨🏼‍❤‍💋‍👨🏿' => 'baxo: òmmo, òmmo, carnaxon assæ ciæa e carnaxon scua',
    '👨🏽‍❤‍💋‍👨🏻' => 'baxo: òmmo, òmmo, carnaxon cô d’öiva e carnaxon ciæa',
    '👨🏽‍❤‍💋‍👨🏼' => 'baxo: òmmo, òmmo, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👨🏽‍❤‍💋‍👨🏽' => 'baxo: òmmo, òmmo e carnaxon cô d’öiva',
    '👨🏽‍❤‍💋‍👨🏾' => 'baxo: òmmo, òmmo, carnaxon cô d’öiva e carnaxon assæ scua',
    '👨🏽‍❤‍💋‍👨🏿' => 'baxo: òmmo, òmmo, carnaxon cô d’öiva e carnaxon scua',
    '👨🏾‍❤‍💋‍👨🏻' => 'baxo: òmmo, òmmo, carnaxon assæ scua e carnaxon ciæa',
    '👨🏾‍❤‍💋‍👨🏼' => 'baxo: òmmo, òmmo, carnaxon assæ scua e carnaxon assæ ciæa',
    '👨🏾‍❤‍💋‍👨🏽' => 'baxo: òmmo, òmmo, carnaxon assæ scua e carnaxon cô d’öiva',
    '👨🏾‍❤‍💋‍👨🏾' => 'baxo: òmmo, òmmo e carnaxon assæ scua',
    '👨🏾‍❤‍💋‍👨🏿' => 'baxo: òmmo, òmmo, carnaxon assæ scua e carnaxon scua',
    '👨🏿‍❤‍💋‍👨🏻' => 'baxo: òmmo, òmmo, carnaxon scua e carnaxon ciæa',
    '👨🏿‍❤‍💋‍👨🏼' => 'baxo: òmmo, òmmo, carnaxon scua e carnaxon assæ ciæa',
    '👨🏿‍❤‍💋‍👨🏽' => 'baxo: òmmo, òmmo, carnaxon scua e carnaxon cô d’öiva',
    '👨🏿‍❤‍💋‍👨🏾' => 'baxo: òmmo, òmmo, carnaxon scua e carnaxon assæ scua',
    '👨🏿‍❤‍💋‍👨🏿' => 'baxo: òmmo, òmmo e carnaxon scua',
    '👩🏻‍❤‍💋‍👨🏻' => 'baxo: dònna, òmmo e carnaxon ciæa',
    '👩🏻‍❤‍💋‍👨🏼' => 'baxo: dònna, òmmo, carnaxon ciæa e carnaxon assæ ciæa',
    '👩🏻‍❤‍💋‍👨🏽' => 'baxo: dònna, òmmo, carnaxon ciæa e carnaxon cô d’öiva',
    '👩🏻‍❤‍💋‍👨🏾' => 'baxo: dònna, òmmo, carnaxon ciæa e carnaxon assæ scua',
    '👩🏻‍❤‍💋‍👨🏿' => 'baxo: dònna, òmmo, carnaxon ciæa e carnaxon scua',
    '👩🏼‍❤‍💋‍👨🏻' => 'baxo: dònna, òmmo, carnaxon assæ ciæa e carnaxon ciæa',
    '👩🏼‍❤‍💋‍👨🏼' => 'baxo: dònna, òmmo e carnaxon assæ ciæa',
    '👩🏼‍❤‍💋‍👨🏽' => 'baxo: dònna, òmmo, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👩🏼‍❤‍💋‍👨🏾' => 'baxo: dònna, òmmo, carnaxon assæ ciæa e carnaxon assæ scua',
    '👩🏼‍❤‍💋‍👨🏿' => 'baxo: dònna, òmmo, carnaxon assæ ciæa e carnaxon scua',
    '👩🏽‍❤‍💋‍👨🏻' => 'baxo: dònna, òmmo, carnaxon cô d’öiva e carnaxon ciæa',
    '👩🏽‍❤‍💋‍👨🏼' => 'baxo: dònna, òmmo, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👩🏽‍❤‍💋‍👨🏽' => 'baxo: dònna, òmmo e carnaxon cô d’öiva',
    '👩🏽‍❤‍💋‍👨🏾' => 'baxo: dònna, òmmo, carnaxon cô d’öiva e carnaxon assæ scua',
    '👩🏽‍❤‍💋‍👨🏿' => 'baxo: dònna, òmmo, carnaxon cô d’öiva e carnaxon scua',
    '👩🏾‍❤‍💋‍👨🏻' => 'baxo: dònna, òmmo, carnaxon assæ scua e carnaxon ciæa',
    '👩🏾‍❤‍💋‍👨🏼' => 'baxo: dònna, òmmo, carnaxon assæ scua e carnaxon assæ ciæa',
    '👩🏾‍❤‍💋‍👨🏽' => 'baxo: dònna, òmmo, carnaxon assæ scua e carnaxon cô d’öiva',
    '👩🏾‍❤‍💋‍👨🏾' => 'baxo: dònna, òmmo e carnaxon assæ scua',
    '👩🏾‍❤‍💋‍👨🏿' => 'baxo: dònna, òmmo, carnaxon assæ scua e carnaxon scua',
    '👩🏿‍❤‍💋‍👨🏻' => 'baxo: dònna, òmmo, carnaxon scua e carnaxon ciæa',
    '👩🏿‍❤‍💋‍👨🏼' => 'baxo: dònna, òmmo, carnaxon scua e carnaxon assæ ciæa',
    '👩🏿‍❤‍💋‍👨🏽' => 'baxo: dònna, òmmo, carnaxon scua e carnaxon cô d’öiva',
    '👩🏿‍❤‍💋‍👨🏾' => 'baxo: dònna, òmmo, carnaxon scua e carnaxon assæ scua',
    '👩🏿‍❤‍💋‍👨🏿' => 'baxo: dònna, òmmo e carnaxon scua',
    '👩🏻‍❤‍💋‍👩🏻' => 'baxo: dònna, dònna e carnaxon ciæa',
    '👩🏻‍❤‍💋‍👩🏼' => 'baxo: dònna, dònna, carnaxon ciæa e carnaxon assæ ciæa',
    '👩🏻‍❤‍💋‍👩🏽' => 'baxo: dònna, dònna, carnaxon ciæa e carnaxon cô d’öiva',
    '👩🏻‍❤‍💋‍👩🏾' => 'baxo: dònna, dònna, carnaxon ciæa e carnaxon assæ scua',
    '👩🏻‍❤‍💋‍👩🏿' => 'baxo: dònna, dònna, carnaxon ciæa e carnaxon scua',
    '👩🏼‍❤‍💋‍👩🏻' => 'baxo: dònna, dònna, carnaxon assæ ciæa e carnaxon ciæa',
    '👩🏼‍❤‍💋‍👩🏼' => 'baxo: dònna, dònna e carnaxon assæ ciæa',
    '👩🏼‍❤‍💋‍👩🏽' => 'baxo: dònna, dònna, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👩🏼‍❤‍💋‍👩🏾' => 'baxo: dònna, dònna, carnaxon assæ ciæa e carnaxon assæ scua',
    '👩🏼‍❤‍💋‍👩🏿' => 'baxo: dònna, dònna, carnaxon assæ ciæa e carnaxon scua',
    '👩🏽‍❤‍💋‍👩🏻' => 'baxo: dònna, dònna, carnaxon cô d’öiva e carnaxon ciæa',
    '👩🏽‍❤‍💋‍👩🏼' => 'baxo: dònna, dònna, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👩🏽‍❤‍💋‍👩🏽' => 'baxo: dònna, dònna e carnaxon cô d’öiva',
    '👩🏽‍❤‍💋‍👩🏾' => 'baxo: dònna, dònna, carnaxon cô d’öiva e carnaxon assæ scua',
    '👩🏽‍❤‍💋‍👩🏿' => 'baxo: dònna, dònna, carnaxon cô d’öiva e carnaxon scua',
    '👩🏾‍❤‍💋‍👩🏻' => 'baxo: dònna, dònna, carnaxon assæ scua e carnaxon ciæa',
    '👩🏾‍❤‍💋‍👩🏼' => 'baxo: dònna, dònna, carnaxon assæ scua e carnaxon assæ ciæa',
    '👩🏾‍❤‍💋‍👩🏽' => 'baxo: dònna, dònna, carnaxon assæ scua e carnaxon cô d’öiva',
    '👩🏾‍❤‍💋‍👩🏾' => 'baxo: dònna, dònna e carnaxon assæ scua',
    '👩🏾‍❤‍💋‍👩🏿' => 'baxo: dònna, dònna, carnaxon assæ scua e carnaxon scua',
    '👩🏿‍❤‍💋‍👩🏻' => 'baxo: dònna, dònna, carnaxon scua e carnaxon ciæa',
    '👩🏿‍❤‍💋‍👩🏼' => 'baxo: dònna, dònna, carnaxon scua e carnaxon assæ ciæa',
    '👩🏿‍❤‍💋‍👩🏽' => 'baxo: dònna, dònna, carnaxon scua e carnaxon cô d’öiva',
    '👩🏿‍❤‍💋‍👩🏾' => 'baxo: dònna, dònna, carnaxon scua e carnaxon assæ scua',
    '👩🏿‍❤‍💋‍👩🏿' => 'baxo: dònna, dònna e carnaxon scua',
    '🧑🏻‍🫯‍🧑🏼' => 'persoñe che lòttan: carnaxon ciæa e carnaxon assæ ciæa',
    '🧑🏻‍🫯‍🧑🏽' => 'persoñe che lòttan: carnaxon ciæa e carnaxon cô d’öiva',
    '🧑🏻‍🫯‍🧑🏾' => 'persoñe che lòttan: carnaxon ciæa e carnaxon assæ scua',
    '🧑🏻‍🫯‍🧑🏿' => 'persoñe che lòttan: carnaxon ciæa e carnaxon scua',
    '🧑🏼‍🫯‍🧑🏻' => 'persoñe che lòttan: carnaxon assæ ciæa e carnaxon ciæa',
    '🧑🏼‍🫯‍🧑🏽' => 'persoñe che lòttan: carnaxon assæ ciæa e carnaxon cô d’öiva',
    '🧑🏼‍🫯‍🧑🏾' => 'persoñe che lòttan: carnaxon assæ ciæa e carnaxon assæ scua',
    '🧑🏼‍🫯‍🧑🏿' => 'persoñe che lòttan: carnaxon assæ ciæa e carnaxon scua',
    '🧑🏽‍🫯‍🧑🏻' => 'persoñe che lòttan: carnaxon cô d’öiva e carnaxon ciæa',
    '🧑🏽‍🫯‍🧑🏼' => 'persoñe che lòttan: carnaxon cô d’öiva e carnaxon assæ ciæa',
    '🧑🏽‍🫯‍🧑🏾' => 'persoñe che lòttan: carnaxon cô d’öiva e carnaxon assæ scua',
    '🧑🏽‍🫯‍🧑🏿' => 'persoñe che lòttan: carnaxon cô d’öiva e carnaxon scua',
    '🧑🏾‍🫯‍🧑🏻' => 'persoñe che lòttan: carnaxon assæ scua e carnaxon ciæa',
    '🧑🏾‍🫯‍🧑🏼' => 'persoñe che lòttan: carnaxon assæ scua e carnaxon assæ ciæa',
    '🧑🏾‍🫯‍🧑🏽' => 'persoñe che lòttan: carnaxon assæ scua e carnaxon cô d’öiva',
    '🧑🏾‍🫯‍🧑🏿' => 'persoñe che lòttan: carnaxon assæ scua e carnaxon scua',
    '🧑🏿‍🫯‍🧑🏻' => 'persoñe che lòttan: carnaxon scua e carnaxon ciæa',
    '🧑🏿‍🫯‍🧑🏼' => 'persoñe che lòttan: carnaxon scua e carnaxon assæ ciæa',
    '🧑🏿‍🫯‍🧑🏽' => 'persoñe che lòttan: carnaxon scua e carnaxon cô d’öiva',
    '🧑🏿‍🫯‍🧑🏾' => 'persoñe che lòttan: carnaxon scua e carnaxon assæ scua',
    '🧑🏻‍❤‍🧑🏼' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon ciæa e carnaxon assæ ciæa',
    '🧑🏻‍❤‍🧑🏽' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon ciæa e carnaxon cô d’öiva',
    '🧑🏻‍❤‍🧑🏾' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon ciæa e carnaxon assæ scua',
    '🧑🏻‍❤‍🧑🏿' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon ciæa e carnaxon scua',
    '🧑🏼‍❤‍🧑🏻' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ ciæa e carnaxon ciæa',
    '🧑🏼‍❤‍🧑🏽' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '🧑🏼‍❤‍🧑🏾' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ ciæa e carnaxon assæ scua',
    '🧑🏼‍❤‍🧑🏿' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ ciæa e carnaxon scua',
    '🧑🏽‍❤‍🧑🏻' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon cô d’öiva e carnaxon ciæa',
    '🧑🏽‍❤‍🧑🏼' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '🧑🏽‍❤‍🧑🏾' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon cô d’öiva e carnaxon assæ scua',
    '🧑🏽‍❤‍🧑🏿' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon cô d’öiva e carnaxon scua',
    '🧑🏾‍❤‍🧑🏻' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ scua e carnaxon ciæa',
    '🧑🏾‍❤‍🧑🏼' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ scua e carnaxon assæ ciæa',
    '🧑🏾‍❤‍🧑🏽' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ scua e carnaxon cô d’öiva',
    '🧑🏾‍❤‍🧑🏿' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon assæ scua e carnaxon scua',
    '🧑🏿‍❤‍🧑🏻' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon scua e carnaxon ciæa',
    '🧑🏿‍❤‍🧑🏼' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon scua e carnaxon assæ ciæa',
    '🧑🏿‍❤‍🧑🏽' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon scua e carnaxon cô d’öiva',
    '🧑🏿‍❤‍🧑🏾' => 'cobbia con cheucobbia co-o cheu: persoña, persoña, carnaxon scua e carnaxon assæ scua',
    '🧑🏻‍🐰‍🧑🏼' => 'persoñe co-e oege da coniggio: carnaxon ciæa e carnaxon assæ ciæa',
    '🧑🏻‍🐰‍🧑🏽' => 'persoñe co-e oege da coniggio: carnaxon ciæa e carnaxon cô d’öiva',
    '🧑🏻‍🐰‍🧑🏾' => 'persoñe co-e oege da coniggio: carnaxon ciæa e carnaxon assæ scua',
    '🧑🏻‍🐰‍🧑🏿' => 'persoñe co-e oege da coniggio: carnaxon ciæa e carnaxon scua',
    '🧑🏼‍🐰‍🧑🏻' => 'persoñe co-e oege da coniggio: carnaxon assæ ciæa e carnaxon ciæa',
    '🧑🏼‍🐰‍🧑🏽' => 'persoñe co-e oege da coniggio: carnaxon assæ ciæa e carnaxon cô d’öiva',
    '🧑🏼‍🐰‍🧑🏾' => 'persoñe co-e oege da coniggio: carnaxon assæ ciæa e carnaxon assæ scua',
    '🧑🏼‍🐰‍🧑🏿' => 'persoñe co-e oege da coniggio: carnaxon assæ ciæa e carnaxon scua',
    '🧑🏽‍🐰‍🧑🏻' => 'persoñe co-e oege da coniggio: carnaxon cô d’öiva e carnaxon ciæa',
    '🧑🏽‍🐰‍🧑🏼' => 'persoñe co-e oege da coniggio: carnaxon cô d’öiva e carnaxon assæ ciæa',
    '🧑🏽‍🐰‍🧑🏾' => 'persoñe co-e oege da coniggio: carnaxon cô d’öiva e carnaxon assæ scua',
    '🧑🏽‍🐰‍🧑🏿' => 'persoñe co-e oege da coniggio: carnaxon cô d’öiva e carnaxon scua',
    '🧑🏾‍🐰‍🧑🏻' => 'persoñe co-e oege da coniggio: carnaxon assæ scua e carnaxon ciæa',
    '🧑🏾‍🐰‍🧑🏼' => 'persoñe co-e oege da coniggio: carnaxon assæ scua e carnaxon assæ ciæa',
    '🧑🏾‍🐰‍🧑🏽' => 'persoñe co-e oege da coniggio: carnaxon assæ scua e carnaxon cô d’öiva',
    '🧑🏾‍🐰‍🧑🏿' => 'persoñe co-e oege da coniggio: carnaxon assæ scua e carnaxon scua',
    '🧑🏿‍🐰‍🧑🏻' => 'persoñe co-e oege da coniggio: carnaxon scua e carnaxon ciæa',
    '🧑🏿‍🐰‍🧑🏼' => 'persoñe co-e oege da coniggio: carnaxon scua e carnaxon assæ ciæa',
    '🧑🏿‍🐰‍🧑🏽' => 'persoñe co-e oege da coniggio: carnaxon scua e carnaxon cô d’öiva',
    '🧑🏿‍🐰‍🧑🏾' => 'persoñe co-e oege da coniggio: carnaxon scua e carnaxon assæ scua',
    '👨🏻‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo e carnaxon ciæa',
    '👨🏻‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon ciæa e carnaxon assæ ciæa',
    '👨🏻‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon ciæa e carnaxon cô d’öiva',
    '👨🏻‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon ciæa e carnaxon assæ scua',
    '👨🏻‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon ciæa e carnaxon scua',
    '👨🏼‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ ciæa e carnaxon ciæa',
    '👨🏼‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo e carnaxon assæ ciæa',
    '👨🏼‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👨🏼‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ ciæa e carnaxon assæ scua',
    '👨🏼‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ ciæa e carnaxon scua',
    '👨🏽‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon cô d’öiva e carnaxon ciæa',
    '👨🏽‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👨🏽‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo e carnaxon cô d’öiva',
    '👨🏽‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon cô d’öiva e carnaxon assæ scua',
    '👨🏽‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon cô d’öiva e carnaxon scua',
    '👨🏾‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ scua e carnaxon ciæa',
    '👨🏾‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ scua e carnaxon assæ ciæa',
    '👨🏾‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ scua e carnaxon cô d’öiva',
    '👨🏾‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo e carnaxon assæ scua',
    '👨🏾‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon assæ scua e carnaxon scua',
    '👨🏿‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon scua e carnaxon ciæa',
    '👨🏿‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon scua e carnaxon assæ ciæa',
    '👨🏿‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon scua e carnaxon cô d’öiva',
    '👨🏿‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo, carnaxon scua e carnaxon assæ scua',
    '👨🏿‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: òmmo, òmmo e carnaxon scua',
    '👩🏻‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo e carnaxon ciæa',
    '👩🏻‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon ciæa e carnaxon assæ ciæa',
    '👩🏻‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon ciæa e carnaxon cô d’öiva',
    '👩🏻‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon ciæa e carnaxon assæ scua',
    '👩🏻‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon ciæa e carnaxon scua',
    '👩🏼‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ ciæa e carnaxon ciæa',
    '👩🏼‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo e carnaxon assæ ciæa',
    '👩🏼‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👩🏼‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ ciæa e carnaxon assæ scua',
    '👩🏼‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ ciæa e carnaxon scua',
    '👩🏽‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon cô d’öiva e carnaxon ciæa',
    '👩🏽‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👩🏽‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo e carnaxon cô d’öiva',
    '👩🏽‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon cô d’öiva e carnaxon assæ scua',
    '👩🏽‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon cô d’öiva e carnaxon scua',
    '👩🏾‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ scua e carnaxon ciæa',
    '👩🏾‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ scua e carnaxon assæ ciæa',
    '👩🏾‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ scua e carnaxon cô d’öiva',
    '👩🏾‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo e carnaxon assæ scua',
    '👩🏾‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon assæ scua e carnaxon scua',
    '👩🏿‍❤‍👨🏻' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon scua e carnaxon ciæa',
    '👩🏿‍❤‍👨🏼' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon scua e carnaxon assæ ciæa',
    '👩🏿‍❤‍👨🏽' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon scua e carnaxon cô d’öiva',
    '👩🏿‍❤‍👨🏾' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo, carnaxon scua e carnaxon assæ scua',
    '👩🏿‍❤‍👨🏿' => 'cobbia con cheucobbia co-o cheu: dònna, òmmo e carnaxon scua',
    '👩🏻‍❤‍👩🏻' => 'cobbia con cheucobbia co-o cheu: dònna, dònna e carnaxon ciæa',
    '👩🏻‍❤‍👩🏼' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon ciæa e carnaxon assæ ciæa',
    '👩🏻‍❤‍👩🏽' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon ciæa e carnaxon cô d’öiva',
    '👩🏻‍❤‍👩🏾' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon ciæa e carnaxon assæ scua',
    '👩🏻‍❤‍👩🏿' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon ciæa e carnaxon scua',
    '👩🏼‍❤‍👩🏻' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ ciæa e carnaxon ciæa',
    '👩🏼‍❤‍👩🏼' => 'cobbia con cheucobbia co-o cheu: dònna, dònna e carnaxon assæ ciæa',
    '👩🏼‍❤‍👩🏽' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👩🏼‍❤‍👩🏾' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ ciæa e carnaxon assæ scua',
    '👩🏼‍❤‍👩🏿' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ ciæa e carnaxon scua',
    '👩🏽‍❤‍👩🏻' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon cô d’öiva e carnaxon ciæa',
    '👩🏽‍❤‍👩🏼' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👩🏽‍❤‍👩🏽' => 'cobbia con cheucobbia co-o cheu: dònna, dònna e carnaxon cô d’öiva',
    '👩🏽‍❤‍👩🏾' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon cô d’öiva e carnaxon assæ scua',
    '👩🏽‍❤‍👩🏿' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon cô d’öiva e carnaxon scua',
    '👩🏾‍❤‍👩🏻' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ scua e carnaxon ciæa',
    '👩🏾‍❤‍👩🏼' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ scua e carnaxon assæ ciæa',
    '👩🏾‍❤‍👩🏽' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ scua e carnaxon cô d’öiva',
    '👩🏾‍❤‍👩🏾' => 'cobbia con cheucobbia co-o cheu: dònna, dònna e carnaxon assæ scua',
    '👩🏾‍❤‍👩🏿' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon assæ scua e carnaxon scua',
    '👩🏿‍❤‍👩🏻' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon scua e carnaxon ciæa',
    '👩🏿‍❤‍👩🏼' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon scua e carnaxon assæ ciæa',
    '👩🏿‍❤‍👩🏽' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon scua e carnaxon cô d’öiva',
    '👩🏿‍❤‍👩🏾' => 'cobbia con cheucobbia co-o cheu: dònna, dònna, carnaxon scua e carnaxon assæ scua',
    '👩🏿‍❤‍👩🏿' => 'cobbia con cheucobbia co-o cheu: dònna, dònna e carnaxon scua',
    '👩🏻‍🤝‍👩🏼' => 'doe dònne che se tëgnan pe-a man: carnaxon ciæa e carnaxon assæ ciæa',
    '👩🏻‍🤝‍👩🏽' => 'doe dònne che se tëgnan pe-a man: carnaxon ciæa e carnaxon cô d’öiva',
    '👩🏻‍🤝‍👩🏾' => 'doe dònne che se tëgnan pe-a man: carnaxon ciæa e carnaxon assæ scua',
    '👩🏻‍🤝‍👩🏿' => 'doe dònne che se tëgnan pe-a man: carnaxon ciæa e carnaxon scua',
    '👩🏼‍🤝‍👩🏻' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon ciæa',
    '👩🏼‍🤝‍👩🏽' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👩🏼‍🤝‍👩🏾' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon assæ scua',
    '👩🏼‍🤝‍👩🏿' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon scua',
    '👩🏽‍🤝‍👩🏻' => 'doe dònne che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon ciæa',
    '👩🏽‍🤝‍👩🏼' => 'doe dònne che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👩🏽‍🤝‍👩🏾' => 'doe dònne che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon assæ scua',
    '👩🏽‍🤝‍👩🏿' => 'doe dònne che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon scua',
    '👩🏾‍🤝‍👩🏻' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ scua e carnaxon ciæa',
    '👩🏾‍🤝‍👩🏼' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ scua e carnaxon assæ ciæa',
    '👩🏾‍🤝‍👩🏽' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ scua e carnaxon cô d’öiva',
    '👩🏾‍🤝‍👩🏿' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ scua e carnaxon scua',
    '👩🏿‍🤝‍👩🏻' => 'doe dònne che se tëgnan pe-a man: carnaxon scua e carnaxon ciæa',
    '👩🏿‍🤝‍👩🏼' => 'doe dònne che se tëgnan pe-a man: carnaxon scua e carnaxon assæ ciæa',
    '👩🏿‍🤝‍👩🏽' => 'doe dònne che se tëgnan pe-a man: carnaxon scua e carnaxon cô d’öiva',
    '👩🏿‍🤝‍👩🏾' => 'doe dònne che se tëgnan pe-a man: carnaxon scua e carnaxon assæ scua',
    '👩🏻‍🤝‍👨🏼' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon ciæa e carnaxon assæ ciæa',
    '👩🏻‍🤝‍👨🏽' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon ciæa e carnaxon cô d’öiva',
    '👩🏻‍🤝‍👨🏾' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon ciæa e carnaxon assæ scua',
    '👩🏻‍🤝‍👨🏿' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon ciæa e carnaxon scua',
    '👩🏼‍🤝‍👨🏻' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon ciæa',
    '👩🏼‍🤝‍👨🏽' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👩🏼‍🤝‍👨🏾' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon assæ scua',
    '👩🏼‍🤝‍👨🏿' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon scua',
    '👩🏽‍🤝‍👨🏻' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon ciæa',
    '👩🏽‍🤝‍👨🏼' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👩🏽‍🤝‍👨🏾' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon assæ scua',
    '👩🏽‍🤝‍👨🏿' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon scua',
    '👩🏾‍🤝‍👨🏻' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ scua e carnaxon ciæa',
    '👩🏾‍🤝‍👨🏼' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ scua e carnaxon assæ ciæa',
    '👩🏾‍🤝‍👨🏽' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ scua e carnaxon cô d’öiva',
    '👩🏾‍🤝‍👨🏿' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ scua e carnaxon scua',
    '👩🏿‍🤝‍👨🏻' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon scua e carnaxon ciæa',
    '👩🏿‍🤝‍👨🏼' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon scua e carnaxon assæ ciæa',
    '👩🏿‍🤝‍👨🏽' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon scua e carnaxon cô d’öiva',
    '👩🏿‍🤝‍👨🏾' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon scua e carnaxon assæ scua',
    '👨🏻‍🤝‍👨🏼' => 'doî òmmi che se tëgnan pe-a man: carnaxon ciæa e carnaxon assæ ciæa',
    '👨🏻‍🤝‍👨🏽' => 'doî òmmi che se tëgnan pe-a man: carnaxon ciæa e carnaxon cô d’öiva',
    '👨🏻‍🤝‍👨🏾' => 'doî òmmi che se tëgnan pe-a man: carnaxon ciæa e carnaxon assæ scua',
    '👨🏻‍🤝‍👨🏿' => 'doî òmmi che se tëgnan pe-a man: carnaxon ciæa e carnaxon scua',
    '👨🏼‍🤝‍👨🏻' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon ciæa',
    '👨🏼‍🤝‍👨🏽' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon cô d’öiva',
    '👨🏼‍🤝‍👨🏾' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon assæ scua',
    '👨🏼‍🤝‍👨🏿' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ ciæa e carnaxon scua',
    '👨🏽‍🤝‍👨🏻' => 'doî òmmi che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon ciæa',
    '👨🏽‍🤝‍👨🏼' => 'doî òmmi che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon assæ ciæa',
    '👨🏽‍🤝‍👨🏾' => 'doî òmmi che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon assæ scua',
    '👨🏽‍🤝‍👨🏿' => 'doî òmmi che se tëgnan pe-a man: carnaxon cô d’öiva e carnaxon scua',
    '👨🏾‍🤝‍👨🏻' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ scua e carnaxon ciæa',
    '👨🏾‍🤝‍👨🏼' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ scua e carnaxon assæ ciæa',
    '👨🏾‍🤝‍👨🏽' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ scua e carnaxon cô d’öiva',
    '👨🏾‍🤝‍👨🏿' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ scua e carnaxon scua',
    '👨🏿‍🤝‍👨🏻' => 'doî òmmi che se tëgnan pe-a man: carnaxon scua e carnaxon ciæa',
    '👨🏿‍🤝‍👨🏼' => 'doî òmmi che se tëgnan pe-a man: carnaxon scua e carnaxon assæ ciæa',
    '👨🏿‍🤝‍👨🏽' => 'doî òmmi che se tëgnan pe-a man: carnaxon scua e carnaxon cô d’öiva',
    '👨🏿‍🤝‍👨🏾' => 'doî òmmi che se tëgnan pe-a man: carnaxon scua e carnaxon assæ scua',
    '👩‍❤‍💋‍👨' => 'baxo: dònna e òmmo',
    '👨‍❤‍💋‍👨' => 'baxo: òmmo e òmmo',
    '👩‍❤‍💋‍👩' => 'baxo: dònna e dònna',
    '👨‍👩‍👧‍👦' => 'famiggia: òmmo, dònna, figgeua e figgeu masccio',
    '👨‍👩‍👦‍👦' => 'famiggia: òmmo, dònna, figgeu masccio e figgeu masccio',
    '👨‍👩‍👧‍👧' => 'famiggia: òmmo, dònna, figgeua e figgeua',
    '👨‍👨‍👧‍👦' => 'famiggia: òmmo, òmmo, figgeua e figgeu masccio',
    '👨‍👨‍👦‍👦' => 'famiggia: òmmo, òmmo, figgeu masccio e figgeu masccio',
    '👨‍👨‍👧‍👧' => 'famiggia: òmmo, òmmo, figgeua e figgeua',
    '👩‍👩‍👧‍👦' => 'famiggia: dònna, dònna, figgeua e figgeu masccio',
    '👩‍👩‍👦‍👦' => 'famiggia: dònna, dònna, figgeu masccio e figgeu masccio',
    '👩‍👩‍👧‍👧' => 'famiggia: dònna, dònna, figgeua e figgeua',
    '🫱🏻‍🫲🏼' => 'toccata de man: carnaxon ciæa e carnaxon assæ ciæa',
    '🫱🏻‍🫲🏽' => 'toccata de man: carnaxon ciæa e carnaxon cô d’öiva',
    '🫱🏻‍🫲🏾' => 'toccata de man: carnaxon ciæa e carnaxon assæ scua',
    '🫱🏻‍🫲🏿' => 'toccata de man: carnaxon ciæa e carnaxon scua',
    '🫱🏼‍🫲🏻' => 'toccata de man: carnaxon assæ ciæa e carnaxon ciæa',
    '🫱🏼‍🫲🏽' => 'toccata de man: carnaxon assæ ciæa e carnaxon cô d’öiva',
    '🫱🏼‍🫲🏾' => 'toccata de man: carnaxon assæ ciæa e carnaxon assæ scua',
    '🫱🏼‍🫲🏿' => 'toccata de man: carnaxon assæ ciæa e carnaxon scua',
    '🫱🏽‍🫲🏻' => 'toccata de man: carnaxon cô d’öiva e carnaxon ciæa',
    '🫱🏽‍🫲🏼' => 'toccata de man: carnaxon cô d’öiva e carnaxon assæ ciæa',
    '🫱🏽‍🫲🏾' => 'toccata de man: carnaxon cô d’öiva e carnaxon assæ scua',
    '🫱🏽‍🫲🏿' => 'toccata de man: carnaxon cô d’öiva e carnaxon scua',
    '🫱🏾‍🫲🏻' => 'toccata de man: carnaxon assæ scua e carnaxon ciæa',
    '🫱🏾‍🫲🏼' => 'toccata de man: carnaxon assæ scua e carnaxon assæ ciæa',
    '🫱🏾‍🫲🏽' => 'toccata de man: carnaxon assæ scua e carnaxon cô d’öiva',
    '🫱🏾‍🫲🏿' => 'toccata de man: carnaxon assæ scua e carnaxon scua',
    '🫱🏿‍🫲🏻' => 'toccata de man: carnaxon scua e carnaxon ciæa',
    '🫱🏿‍🫲🏼' => 'toccata de man: carnaxon scua e carnaxon assæ ciæa',
    '🫱🏿‍🫲🏽' => 'toccata de man: carnaxon scua e carnaxon cô d’öiva',
    '🫱🏿‍🫲🏾' => 'toccata de man: carnaxon scua e carnaxon assæ scua',
    '👩‍❤‍👨' => 'cobbia con cheucobbia co-o cheu: dònna e òmmo',
    '👨‍❤‍👨' => 'cobbia con cheucobbia co-o cheu: òmmo e òmmo',
    '👩‍❤‍👩' => 'cobbia con cheucobbia co-o cheu: dònna e dònna',
    '👨‍👩‍👦' => 'famiggia: òmmo, dònna e figgeu masccio',
    '👨‍👩‍👧' => 'famiggia: òmmo, dònna e figgeua',
    '👨‍👨‍👦' => 'famiggia: òmmo, òmmo e figgeu masccio',
    '👨‍👨‍👧' => 'famiggia: òmmo, òmmo e figgeua',
    '👩‍👩‍👦' => 'famiggia: dònna, dònna e figgeu masccio',
    '👩‍👩‍👧' => 'famiggia: dònna, dònna e figgeua',
    '👨‍👦‍👦' => 'famiggia: òmmo, figgeu masccio e figgeu masccio',
    '👨‍👧‍👦' => 'famiggia: òmmo, figgeua e figgeu masccio',
    '👨‍👧‍👧' => 'famiggia: òmmo, figgeua e figgeua',
    '👩‍👦‍👦' => 'famiggia: dònna, figgeu masccio e figgeu masccio',
    '👩‍👧‍👦' => 'famiggia: dònna, figgeua e figgeu masccio',
    '👩‍👧‍👧' => 'famiggia: dònna, figgeua e figgeua',
    '🧑🏻‍🦰' => 'persoña: carnaxon ciæa e cavelli rosci',
    '🧑🏼‍🦰' => 'persoña: carnaxon assæ ciæa e cavelli rosci',
    '🧑🏽‍🦰' => 'persoña: carnaxon cô d’öiva e cavelli rosci',
    '🧑🏾‍🦰' => 'persoña: carnaxon assæ scua e cavelli rosci',
    '🧑🏿‍🦰' => 'persoña: carnaxon scua e cavelli rosci',
    '🧑🏻‍🦱' => 'persoña: carnaxon ciæa e cavelli arrissoxi',
    '🧑🏼‍🦱' => 'persoña: carnaxon assæ ciæa e cavelli arrissoxi',
    '🧑🏽‍🦱' => 'persoña: carnaxon cô d’öiva e cavelli arrissoxi',
    '🧑🏾‍🦱' => 'persoña: carnaxon assæ scua e cavelli arrissoxi',
    '🧑🏿‍🦱' => 'persoña: carnaxon scua e cavelli arrissoxi',
    '🧑🏻‍🦳' => 'persoña: carnaxon ciæa e cavelli gianchi',
    '🧑🏼‍🦳' => 'persoña: carnaxon assæ ciæa e cavelli gianchi',
    '🧑🏽‍🦳' => 'persoña: carnaxon cô d’öiva e cavelli gianchi',
    '🧑🏾‍🦳' => 'persoña: carnaxon assæ scua e cavelli gianchi',
    '🧑🏿‍🦳' => 'persoña: carnaxon scua e cavelli gianchi',
    '🧑🏻‍🦲' => 'persoña: carnaxon ciæa e peou',
    '🧑🏼‍🦲' => 'persoña: carnaxon assæ ciæa e peou',
    '🧑🏽‍🦲' => 'persoña: carnaxon cô d’öiva e peou',
    '🧑🏾‍🦲' => 'persoña: carnaxon assæ scua e peou',
    '🧑🏿‍🦲' => 'persoña: carnaxon scua e peou',
    '👨🏻‍🦰' => 'òmmo: carnaxon ciæa e cavelli rosci',
    '👨🏼‍🦰' => 'òmmo: carnaxon assæ ciæa e cavelli rosci',
    '👨🏽‍🦰' => 'òmmo: carnaxon cô d’öiva e cavelli rosci',
    '👨🏾‍🦰' => 'òmmo: carnaxon assæ scua e cavelli rosci',
    '👨🏿‍🦰' => 'òmmo: carnaxon scua e cavelli rosci',
    '👨🏻‍🦱' => 'òmmo: carnaxon ciæa e cavelli arrissoxi',
    '👨🏼‍🦱' => 'òmmo: carnaxon assæ ciæa e cavelli arrissoxi',
    '👨🏽‍🦱' => 'òmmo: carnaxon cô d’öiva e cavelli arrissoxi',
    '👨🏾‍🦱' => 'òmmo: carnaxon assæ scua e cavelli arrissoxi',
    '👨🏿‍🦱' => 'òmmo: carnaxon scua e cavelli arrissoxi',
    '👨🏻‍🦳' => 'òmmo: carnaxon ciæa e cavelli gianchi',
    '👨🏼‍🦳' => 'òmmo: carnaxon assæ ciæa e cavelli gianchi',
    '👨🏽‍🦳' => 'òmmo: carnaxon cô d’öiva e cavelli gianchi',
    '👨🏾‍🦳' => 'òmmo: carnaxon assæ scua e cavelli gianchi',
    '👨🏿‍🦳' => 'òmmo: carnaxon scua e cavelli gianchi',
    '👨🏻‍🦲' => 'òmmo: carnaxon ciæa e peou',
    '👨🏼‍🦲' => 'òmmo: carnaxon assæ ciæa e peou',
    '👨🏽‍🦲' => 'òmmo: carnaxon cô d’öiva e peou',
    '👨🏾‍🦲' => 'òmmo: carnaxon assæ scua e peou',
    '👨🏿‍🦲' => 'òmmo: carnaxon scua e peou',
    '👩🏻‍🦰' => 'dònna: carnaxon ciæa e cavelli rosci',
    '👩🏼‍🦰' => 'dònna: carnaxon assæ ciæa e cavelli rosci',
    '👩🏽‍🦰' => 'dònna: carnaxon cô d’öiva e cavelli rosci',
    '👩🏾‍🦰' => 'dònna: carnaxon assæ scua e cavelli rosci',
    '👩🏿‍🦰' => 'dònna: carnaxon scua e cavelli rosci',
    '👩🏻‍🦱' => 'dònna: carnaxon ciæa e cavelli arrissoxi',
    '👩🏼‍🦱' => 'dònna: carnaxon assæ ciæa e cavelli arrissoxi',
    '👩🏽‍🦱' => 'dònna: carnaxon cô d’öiva e cavelli arrissoxi',
    '👩🏾‍🦱' => 'dònna: carnaxon assæ scua e cavelli arrissoxi',
    '👩🏿‍🦱' => 'dònna: carnaxon scua e cavelli arrissoxi',
    '👩🏻‍🦳' => 'dònna: carnaxon ciæa e cavelli gianchi',
    '👩🏼‍🦳' => 'dònna: carnaxon assæ ciæa e cavelli gianchi',
    '👩🏽‍🦳' => 'dònna: carnaxon cô d’öiva e cavelli gianchi',
    '👩🏾‍🦳' => 'dònna: carnaxon assæ scua e cavelli gianchi',
    '👩🏿‍🦳' => 'dònna: carnaxon scua e cavelli gianchi',
    '👩🏻‍🦲' => 'dònna: carnaxon ciæa e peou',
    '👩🏼‍🦲' => 'dònna: carnaxon assæ ciæa e peou',
    '👩🏽‍🦲' => 'dònna: carnaxon cô d’öiva e peou',
    '👩🏾‍🦲' => 'dònna: carnaxon assæ scua e peou',
    '👩🏿‍🦲' => 'dònna: carnaxon scua e peou',
    '🧑‍🦰' => 'persoña: cavelli rosci',
    '🧑‍🦱' => 'persoña: cavelli arrissoxi',
    '🧑‍🦳' => 'persoña: cavelli gianchi',
    '🧑‍🦲' => 'persoña: peou',
    '👨‍🦰' => 'òmmo: cavelli rosci',
    '👨‍🦱' => 'òmmo: cavelli arrissoxi',
    '👨‍🦳' => 'òmmo: cavelli gianchi',
    '👨‍🦲' => 'òmmo: peou',
    '👩‍🦰' => 'dònna: cavelli rosci',
    '👩‍🦱' => 'dònna: cavelli arrissoxi',
    '👩‍🦳' => 'dònna: cavelli gianchi',
    '👩‍🦲' => 'dònna: peou',
    '👨‍👦' => 'famiggia: òmmo e figgeu masccio',
    '👨‍👧' => 'famiggia: òmmo e figgeua',
    '👩‍👦' => 'famiggia: dònna e figgeu masccio',
    '👩‍👧' => 'famiggia: dònna e figgeua',
    '👋🏻' => 'man ch’a salua: carnaxon ciæa',
    '👋🏼' => 'man ch’a salua: carnaxon assæ ciæa',
    '👋🏽' => 'man ch’a salua: carnaxon cô d’öiva',
    '👋🏾' => 'man ch’a salua: carnaxon assæ scua',
    '👋🏿' => 'man ch’a salua: carnaxon scua',
    '🤚🏻' => 'dorso da man arsou: carnaxon ciæa',
    '🤚🏼' => 'dorso da man arsou: carnaxon assæ ciæa',
    '🤚🏽' => 'dorso da man arsou: carnaxon cô d’öiva',
    '🤚🏾' => 'dorso da man arsou: carnaxon assæ scua',
    '🤚🏿' => 'dorso da man arsou: carnaxon scua',
    '🖐🏻' => 'man averta: carnaxon ciæa',
    '🖐🏼' => 'man averta: carnaxon assæ ciæa',
    '🖐🏽' => 'man averta: carnaxon cô d’öiva',
    '🖐🏾' => 'man averta: carnaxon assæ scua',
    '🖐🏿' => 'man averta: carnaxon scua',
    '✋🏻' => 'man arsâ: carnaxon ciæa',
    '✋🏼' => 'man arsâ: carnaxon assæ ciæa',
    '✋🏽' => 'man arsâ: carnaxon cô d’öiva',
    '✋🏾' => 'man arsâ: carnaxon assæ scua',
    '✋🏿' => 'man arsâ: carnaxon scua',
    '🖖🏻' => 'saluo vulcanian: carnaxon ciæa',
    '🖖🏼' => 'saluo vulcanian: carnaxon assæ ciæa',
    '🖖🏽' => 'saluo vulcanian: carnaxon cô d’öiva',
    '🖖🏾' => 'saluo vulcanian: carnaxon assæ scua',
    '🖖🏿' => 'saluo vulcanian: carnaxon scua',
    '🫱🏻' => 'man a-a drita: carnaxon ciæa',
    '🫱🏼' => 'man a-a drita: carnaxon assæ ciæa',
    '🫱🏽' => 'man a-a drita: carnaxon cô d’öiva',
    '🫱🏾' => 'man a-a drita: carnaxon assæ scua',
    '🫱🏿' => 'man a-a drita: carnaxon scua',
    '🫲🏻' => 'man a-a manciña: carnaxon ciæa',
    '🫲🏼' => 'man a-a manciña: carnaxon assæ ciæa',
    '🫲🏽' => 'man a-a manciña: carnaxon cô d’öiva',
    '🫲🏾' => 'man a-a manciña: carnaxon assæ scua',
    '🫲🏿' => 'man a-a manciña: carnaxon scua',
    '🫳🏻' => 'man co-o parmo in zu: carnaxon ciæa',
    '🫳🏼' => 'man co-o parmo in zu: carnaxon assæ ciæa',
    '🫳🏽' => 'man co-o parmo in zu: carnaxon cô d’öiva',
    '🫳🏾' => 'man co-o parmo in zu: carnaxon assæ scua',
    '🫳🏿' => 'man co-o parmo in zu: carnaxon scua',
    '🫴🏻' => 'man co-o parmo in sciù: carnaxon ciæa',
    '🫴🏼' => 'man co-o parmo in sciù: carnaxon assæ ciæa',
    '🫴🏽' => 'man co-o parmo in sciù: carnaxon cô d’öiva',
    '🫴🏾' => 'man co-o parmo in sciù: carnaxon assæ scua',
    '🫴🏿' => 'man co-o parmo in sciù: carnaxon scua',
    '🫷🏻' => 'man ch’a sponcia a-a manciña: carnaxon ciæa',
    '🫷🏼' => 'man ch’a sponcia a-a manciña: carnaxon assæ ciæa',
    '🫷🏽' => 'man ch’a sponcia a-a manciña: carnaxon cô d’öiva',
    '🫷🏾' => 'man ch’a sponcia a-a manciña: carnaxon assæ scua',
    '🫷🏿' => 'man ch’a sponcia a-a manciña: carnaxon scua',
    '🫸🏻' => 'man ch’a sponcia a-a drita: carnaxon ciæa',
    '🫸🏼' => 'man ch’a sponcia a-a drita: carnaxon assæ ciæa',
    '🫸🏽' => 'man ch’a sponcia a-a drita: carnaxon cô d’öiva',
    '🫸🏾' => 'man ch’a sponcia a-a drita: carnaxon assæ scua',
    '🫸🏿' => 'man ch’a sponcia a-a drita: carnaxon scua',
    '👌🏻' => 'man ch’a fa OK: carnaxon ciæa',
    '👌🏼' => 'man ch’a fa OK: carnaxon assæ ciæa',
    '👌🏽' => 'man ch’a fa OK: carnaxon cô d’öiva',
    '👌🏾' => 'man ch’a fa OK: carnaxon assæ scua',
    '👌🏿' => 'man ch’a fa OK: carnaxon scua',
    '🤌🏻' => 'man à pigna: carnaxon ciæa',
    '🤌🏼' => 'man à pigna: carnaxon assæ ciæa',
    '🤌🏽' => 'man à pigna: carnaxon cô d’öiva',
    '🤌🏾' => 'man à pigna: carnaxon assæ scua',
    '🤌🏿' => 'man à pigna: carnaxon scua',
    '🤏🏻' => 'man ch’a spellinsega: carnaxon ciæa',
    '🤏🏼' => 'man ch’a spellinsega: carnaxon assæ ciæa',
    '🤏🏽' => 'man ch’a spellinsega: carnaxon cô d’öiva',
    '🤏🏾' => 'man ch’a spellinsega: carnaxon assæ scua',
    '🤏🏿' => 'man ch’a spellinsega: carnaxon scua',
    '✌🏻' => 'gesto de vittöia: carnaxon ciæa',
    '✌🏼' => 'gesto de vittöia: carnaxon assæ ciæa',
    '✌🏽' => 'gesto de vittöia: carnaxon cô d’öiva',
    '✌🏾' => 'gesto de vittöia: carnaxon assæ scua',
    '✌🏿' => 'gesto de vittöia: carnaxon scua',
    '🤞🏻' => 'die incroxæ: carnaxon ciæa',
    '🤞🏼' => 'die incroxæ: carnaxon assæ ciæa',
    '🤞🏽' => 'die incroxæ: carnaxon cô d’öiva',
    '🤞🏾' => 'die incroxæ: carnaxon assæ scua',
    '🤞🏿' => 'die incroxæ: carnaxon scua',
    '🫰🏻' => 'man con dio longâ e gròsso incroxæ: carnaxon ciæa',
    '🫰🏼' => 'man con dio longâ e gròsso incroxæ: carnaxon assæ ciæa',
    '🫰🏽' => 'man con dio longâ e gròsso incroxæ: carnaxon cô d’öiva',
    '🫰🏾' => 'man con dio longâ e gròsso incroxæ: carnaxon assæ scua',
    '🫰🏿' => 'man con dio longâ e gròsso incroxæ: carnaxon scua',
    '🤟🏻' => 'gesto t’ammo: carnaxon ciæa',
    '🤟🏼' => 'gesto t’ammo: carnaxon assæ ciæa',
    '🤟🏽' => 'gesto t’ammo: carnaxon cô d’öiva',
    '🤟🏾' => 'gesto t’ammo: carnaxon assæ scua',
    '🤟🏿' => 'gesto t’ammo: carnaxon scua',
    '🤘🏻' => 'gesto de còrne: carnaxon ciæa',
    '🤘🏼' => 'gesto de còrne: carnaxon assæ ciæa',
    '🤘🏽' => 'gesto de còrne: carnaxon cô d’öiva',
    '🤘🏾' => 'gesto de còrne: carnaxon assæ scua',
    '🤘🏿' => 'gesto de còrne: carnaxon scua',
    '🤙🏻' => 'gesto ciammime: carnaxon ciæa',
    '🤙🏼' => 'gesto ciammime: carnaxon assæ ciæa',
    '🤙🏽' => 'gesto ciammime: carnaxon cô d’öiva',
    '🤙🏾' => 'gesto ciammime: carnaxon assæ scua',
    '🤙🏿' => 'gesto ciammime: carnaxon scua',
    '👈🏻' => 'dorso da man ch’a mostra a-a manciña: carnaxon ciæa',
    '👈🏼' => 'dorso da man ch’a mostra a-a manciña: carnaxon assæ ciæa',
    '👈🏽' => 'dorso da man ch’a mostra a-a manciña: carnaxon cô d’öiva',
    '👈🏾' => 'dorso da man ch’a mostra a-a manciña: carnaxon assæ scua',
    '👈🏿' => 'dorso da man ch’a mostra a-a manciña: carnaxon scua',
    '👉🏻' => 'dorso da man ch’a mostra a-a drita: carnaxon ciæa',
    '👉🏼' => 'dorso da man ch’a mostra a-a drita: carnaxon assæ ciæa',
    '👉🏽' => 'dorso da man ch’a mostra a-a drita: carnaxon cô d’öiva',
    '👉🏾' => 'dorso da man ch’a mostra a-a drita: carnaxon assæ scua',
    '👉🏿' => 'dorso da man ch’a mostra a-a drita: carnaxon scua',
    '👆🏻' => 'dorso da man ch’a mostra in sciù: carnaxon ciæa',
    '👆🏼' => 'dorso da man ch’a mostra in sciù: carnaxon assæ ciæa',
    '👆🏽' => 'dorso da man ch’a mostra in sciù: carnaxon cô d’öiva',
    '👆🏾' => 'dorso da man ch’a mostra in sciù: carnaxon assæ scua',
    '👆🏿' => 'dorso da man ch’a mostra in sciù: carnaxon scua',
    '🖕🏻' => 'dio de mezo: carnaxon ciæa',
    '🖕🏼' => 'dio de mezo: carnaxon assæ ciæa',
    '🖕🏽' => 'dio de mezo: carnaxon cô d’öiva',
    '🖕🏾' => 'dio de mezo: carnaxon assæ scua',
    '🖕🏿' => 'dio de mezo: carnaxon scua',
    '👇🏻' => 'dorso da man ch’a mostra in zu: carnaxon ciæa',
    '👇🏼' => 'dorso da man ch’a mostra in zu: carnaxon assæ ciæa',
    '👇🏽' => 'dorso da man ch’a mostra in zu: carnaxon cô d’öiva',
    '👇🏾' => 'dorso da man ch’a mostra in zu: carnaxon assæ scua',
    '👇🏿' => 'dorso da man ch’a mostra in zu: carnaxon scua',
    '☝🏻' => 'dio longâ ch’o ponta in sciù: carnaxon ciæa',
    '☝🏼' => 'dio longâ ch’o ponta in sciù: carnaxon assæ ciæa',
    '☝🏽' => 'dio longâ ch’o ponta in sciù: carnaxon cô d’öiva',
    '☝🏾' => 'dio longâ ch’o ponta in sciù: carnaxon assæ scua',
    '☝🏿' => 'dio longâ ch’o ponta in sciù: carnaxon scua',
    '🫵🏻' => 'dio longâ ch’o ponta à l’osservatô: carnaxon ciæa',
    '🫵🏼' => 'dio longâ ch’o ponta à l’osservatô: carnaxon assæ ciæa',
    '🫵🏽' => 'dio longâ ch’o ponta à l’osservatô: carnaxon cô d’öiva',
    '🫵🏾' => 'dio longâ ch’o ponta à l’osservatô: carnaxon assæ scua',
    '🫵🏿' => 'dio longâ ch’o ponta à l’osservatô: carnaxon scua',
    '👍🏻' => 'dio gròsso in sciù: carnaxon ciæa',
    '👍🏼' => 'dio gròsso in sciù: carnaxon assæ ciæa',
    '👍🏽' => 'dio gròsso in sciù: carnaxon cô d’öiva',
    '👍🏾' => 'dio gròsso in sciù: carnaxon assæ scua',
    '👍🏿' => 'dio gròsso in sciù: carnaxon scua',
    '👎🏻' => 'dio gròsso in zu: carnaxon ciæa',
    '👎🏼' => 'dio gròsso in zu: carnaxon assæ ciæa',
    '👎🏽' => 'dio gròsso in zu: carnaxon cô d’öiva',
    '👎🏾' => 'dio gròsso in zu: carnaxon assæ scua',
    '👎🏿' => 'dio gròsso in zu: carnaxon scua',
    '✊🏻' => 'pugno arsou: carnaxon ciæa',
    '✊🏼' => 'pugno arsou: carnaxon assæ ciæa',
    '✊🏽' => 'pugno arsou: carnaxon cô d’öiva',
    '✊🏾' => 'pugno arsou: carnaxon assæ scua',
    '✊🏿' => 'pugno arsou: carnaxon scua',
    '👊🏻' => 'pugno ch’o l’arriva: carnaxon ciæa',
    '👊🏼' => 'pugno ch’o l’arriva: carnaxon assæ ciæa',
    '👊🏽' => 'pugno ch’o l’arriva: carnaxon cô d’öiva',
    '👊🏾' => 'pugno ch’o l’arriva: carnaxon assæ scua',
    '👊🏿' => 'pugno ch’o l’arriva: carnaxon scua',
    '🤛🏻' => 'pugno a-a manciña: carnaxon ciæa',
    '🤛🏼' => 'pugno a-a manciña: carnaxon assæ ciæa',
    '🤛🏽' => 'pugno a-a manciña: carnaxon cô d’öiva',
    '🤛🏾' => 'pugno a-a manciña: carnaxon assæ scua',
    '🤛🏿' => 'pugno a-a manciña: carnaxon scua',
    '🤜🏻' => 'pugno a-a drita: carnaxon ciæa',
    '🤜🏼' => 'pugno a-a drita: carnaxon assæ ciæa',
    '🤜🏽' => 'pugno a-a drita: carnaxon cô d’öiva',
    '🤜🏾' => 'pugno a-a drita: carnaxon assæ scua',
    '🤜🏿' => 'pugno a-a drita: carnaxon scua',
    '👏🏻' => 'cioccâ de moen: carnaxon ciæa',
    '👏🏼' => 'cioccâ de moen: carnaxon assæ ciæa',
    '👏🏽' => 'cioccâ de moen: carnaxon cô d’öiva',
    '👏🏾' => 'cioccâ de moen: carnaxon assæ scua',
    '👏🏿' => 'cioccâ de moen: carnaxon scua',
    '🙌🏻' => 'moen arsæ: carnaxon ciæa',
    '🙌🏼' => 'moen arsæ: carnaxon assæ ciæa',
    '🙌🏽' => 'moen arsæ: carnaxon cô d’öiva',
    '🙌🏾' => 'moen arsæ: carnaxon assæ scua',
    '🙌🏿' => 'moen arsæ: carnaxon scua',
    '🫶🏻' => 'moen à cheu: carnaxon ciæa',
    '🫶🏼' => 'moen à cheu: carnaxon assæ ciæa',
    '🫶🏽' => 'moen à cheu: carnaxon cô d’öiva',
    '🫶🏾' => 'moen à cheu: carnaxon assæ scua',
    '🫶🏿' => 'moen à cheu: carnaxon scua',
    '👐🏻' => 'moen averte: carnaxon ciæa',
    '👐🏼' => 'moen averte: carnaxon assæ ciæa',
    '👐🏽' => 'moen averte: carnaxon cô d’öiva',
    '👐🏾' => 'moen averte: carnaxon assæ scua',
    '👐🏿' => 'moen averte: carnaxon scua',
    '🤲🏻' => 'parmi in sciù assemme: carnaxon ciæa',
    '🤲🏼' => 'parmi in sciù assemme: carnaxon assæ ciæa',
    '🤲🏽' => 'parmi in sciù assemme: carnaxon cô d’öiva',
    '🤲🏾' => 'parmi in sciù assemme: carnaxon assæ scua',
    '🤲🏿' => 'parmi in sciù assemme: carnaxon scua',
    '🤝🏻' => 'toccata de man: carnaxon ciæa',
    '🤝🏼' => 'toccata de man: carnaxon assæ ciæa',
    '🤝🏽' => 'toccata de man: carnaxon cô d’öiva',
    '🤝🏾' => 'toccata de man: carnaxon assæ scua',
    '🤝🏿' => 'toccata de man: carnaxon scua',
    '🙏🏻' => 'moen azzonte: carnaxon ciæa',
    '🙏🏼' => 'moen azzonte: carnaxon assæ ciæa',
    '🙏🏽' => 'moen azzonte: carnaxon cô d’öiva',
    '🙏🏾' => 'moen azzonte: carnaxon assæ scua',
    '🙏🏿' => 'moen azzonte: carnaxon scua',
    '✍🏻' => 'man ch’a scrive: carnaxon ciæa',
    '✍🏼' => 'man ch’a scrive: carnaxon assæ ciæa',
    '✍🏽' => 'man ch’a scrive: carnaxon cô d’öiva',
    '✍🏾' => 'man ch’a scrive: carnaxon assæ scua',
    '✍🏿' => 'man ch’a scrive: carnaxon scua',
    '💅🏻' => 'smato pe onge: carnaxon ciæa',
    '💅🏼' => 'smato pe onge: carnaxon assæ ciæa',
    '💅🏽' => 'smato pe onge: carnaxon cô d’öiva',
    '💅🏾' => 'smato pe onge: carnaxon assæ scua',
    '💅🏿' => 'smato pe onge: carnaxon scua',
    '🤳🏻' => 'selfie: carnaxon ciæa',
    '🤳🏼' => 'selfie: carnaxon assæ ciæa',
    '🤳🏽' => 'selfie: carnaxon cô d’öiva',
    '🤳🏾' => 'selfie: carnaxon assæ scua',
    '🤳🏿' => 'selfie: carnaxon scua',
    '💪🏻' => 'biçipite contræto: carnaxon ciæa',
    '💪🏼' => 'biçipite contræto: carnaxon assæ ciæa',
    '💪🏽' => 'biçipite contræto: carnaxon cô d’öiva',
    '💪🏾' => 'biçipite contræto: carnaxon assæ scua',
    '💪🏿' => 'biçipite contræto: carnaxon scua',
    '🦵🏻' => 'gamba: carnaxon ciæa',
    '🦵🏼' => 'gamba: carnaxon assæ ciæa',
    '🦵🏽' => 'gamba: carnaxon cô d’öiva',
    '🦵🏾' => 'gamba: carnaxon assæ scua',
    '🦵🏿' => 'gamba: carnaxon scua',
    '🦶🏻' => 'pê: carnaxon ciæa',
    '🦶🏼' => 'pê: carnaxon assæ ciæa',
    '🦶🏽' => 'pê: carnaxon cô d’öiva',
    '🦶🏾' => 'pê: carnaxon assæ scua',
    '🦶🏿' => 'pê: carnaxon scua',
    '👂🏻' => 'oegia: carnaxon ciæa',
    '👂🏼' => 'oegia: carnaxon assæ ciæa',
    '👂🏽' => 'oegia: carnaxon cô d’öiva',
    '👂🏾' => 'oegia: carnaxon assæ scua',
    '👂🏿' => 'oegia: carnaxon scua',
    '🦻🏻' => 'oegia con appægio pe sentî: carnaxon ciæa',
    '🦻🏼' => 'oegia con appægio pe sentî: carnaxon assæ ciæa',
    '🦻🏽' => 'oegia con appægio pe sentî: carnaxon cô d’öiva',
    '🦻🏾' => 'oegia con appægio pe sentî: carnaxon assæ scua',
    '🦻🏿' => 'oegia con appægio pe sentî: carnaxon scua',
    '👃🏻' => 'naso: carnaxon ciæa',
    '👃🏼' => 'naso: carnaxon assæ ciæa',
    '👃🏽' => 'naso: carnaxon cô d’öiva',
    '👃🏾' => 'naso: carnaxon assæ scua',
    '👃🏿' => 'naso: carnaxon scua',
    '👶🏻' => 'figgeu da nascion: carnaxon ciæa',
    '👶🏼' => 'figgeu da nascion: carnaxon assæ ciæa',
    '👶🏽' => 'figgeu da nascion: carnaxon cô d’öiva',
    '👶🏾' => 'figgeu da nascion: carnaxon assæ scua',
    '👶🏿' => 'figgeu da nascion: carnaxon scua',
    '🧒🏻' => 'figgeu: carnaxon ciæa',
    '🧒🏼' => 'figgeu: carnaxon assæ ciæa',
    '🧒🏽' => 'figgeu: carnaxon cô d’öiva',
    '🧒🏾' => 'figgeu: carnaxon assæ scua',
    '🧒🏿' => 'figgeu: carnaxon scua',
    '👦🏻' => 'figgeu masccio: carnaxon ciæa',
    '👦🏼' => 'figgeu masccio: carnaxon assæ ciæa',
    '👦🏽' => 'figgeu masccio: carnaxon cô d’öiva',
    '👦🏾' => 'figgeu masccio: carnaxon assæ scua',
    '👦🏿' => 'figgeu masccio: carnaxon scua',
    '👧🏻' => 'figgeua: carnaxon ciæa',
    '👧🏼' => 'figgeua: carnaxon assæ ciæa',
    '👧🏽' => 'figgeua: carnaxon cô d’öiva',
    '👧🏾' => 'figgeua: carnaxon assæ scua',
    '👧🏿' => 'figgeua: carnaxon scua',
    '🧑🏻' => 'persoña: carnaxon ciæa',
    '🧑🏼' => 'persoña: carnaxon assæ ciæa',
    '🧑🏽' => 'persoña: carnaxon cô d’öiva',
    '🧑🏾' => 'persoña: carnaxon assæ scua',
    '🧑🏿' => 'persoña: carnaxon scua',
    '👱🏻' => 'persoña bionda: carnaxon ciæa',
    '👱🏼' => 'persoña bionda: carnaxon assæ ciæa',
    '👱🏽' => 'persoña bionda: carnaxon cô d’öiva',
    '👱🏾' => 'persoña bionda: carnaxon assæ scua',
    '👱🏿' => 'persoña bionda: carnaxon scua',
    '👨🏻' => 'òmmo: carnaxon ciæa',
    '👨🏼' => 'òmmo: carnaxon assæ ciæa',
    '👨🏽' => 'òmmo: carnaxon cô d’öiva',
    '👨🏾' => 'òmmo: carnaxon assæ scua',
    '👨🏿' => 'òmmo: carnaxon scua',
    '🧔🏻' => 'persoña co-a barba: carnaxon ciæa',
    '🧔🏼' => 'persoña co-a barba: carnaxon assæ ciæa',
    '🧔🏽' => 'persoña co-a barba: carnaxon cô d’öiva',
    '🧔🏾' => 'persoña co-a barba: carnaxon assæ scua',
    '🧔🏿' => 'persoña co-a barba: carnaxon scua',
    '👩🏻' => 'dònna: carnaxon ciæa',
    '👩🏼' => 'dònna: carnaxon assæ ciæa',
    '👩🏽' => 'dònna: carnaxon cô d’öiva',
    '👩🏾' => 'dònna: carnaxon assæ scua',
    '👩🏿' => 'dònna: carnaxon scua',
    '🧓🏻' => 'persoña in etæ: carnaxon ciæa',
    '🧓🏼' => 'persoña in etæ: carnaxon assæ ciæa',
    '🧓🏽' => 'persoña in etæ: carnaxon cô d’öiva',
    '🧓🏾' => 'persoña in etæ: carnaxon assæ scua',
    '🧓🏿' => 'persoña in etæ: carnaxon scua',
    '👴🏻' => 'òmmo in etæ: carnaxon ciæa',
    '👴🏼' => 'òmmo in etæ: carnaxon assæ ciæa',
    '👴🏽' => 'òmmo in etæ: carnaxon cô d’öiva',
    '👴🏾' => 'òmmo in etæ: carnaxon assæ scua',
    '👴🏿' => 'òmmo in etæ: carnaxon scua',
    '👵🏻' => 'dònna in etæ: carnaxon ciæa',
    '👵🏼' => 'dònna in etæ: carnaxon assæ ciæa',
    '👵🏽' => 'dònna in etæ: carnaxon cô d’öiva',
    '👵🏾' => 'dònna in etæ: carnaxon assæ scua',
    '👵🏿' => 'dònna in etæ: carnaxon scua',
    '🙍🏻' => 'persoña ammagonâ: carnaxon ciæa',
    '🙍🏼' => 'persoña ammagonâ: carnaxon assæ ciæa',
    '🙍🏽' => 'persoña ammagonâ: carnaxon cô d’öiva',
    '🙍🏾' => 'persoña ammagonâ: carnaxon assæ scua',
    '🙍🏿' => 'persoña ammagonâ: carnaxon scua',
    '🙎🏻' => 'persoña inmoronâ: carnaxon ciæa',
    '🙎🏼' => 'persoña inmoronâ: carnaxon assæ ciæa',
    '🙎🏽' => 'persoña inmoronâ: carnaxon cô d’öiva',
    '🙎🏾' => 'persoña inmoronâ: carnaxon assæ scua',
    '🙎🏿' => 'persoña inmoronâ: carnaxon scua',
    '🙅🏻' => 'persoña ch’a fa segno de no: carnaxon ciæa',
    '🙅🏼' => 'persoña ch’a fa segno de no: carnaxon assæ ciæa',
    '🙅🏽' => 'persoña ch’a fa segno de no: carnaxon cô d’öiva',
    '🙅🏾' => 'persoña ch’a fa segno de no: carnaxon assæ scua',
    '🙅🏿' => 'persoña ch’a fa segno de no: carnaxon scua',
    '🙆🏻' => 'persoña ch’a fa OK: carnaxon ciæa',
    '🙆🏼' => 'persoña ch’a fa OK: carnaxon assæ ciæa',
    '🙆🏽' => 'persoña ch’a fa OK: carnaxon cô d’öiva',
    '🙆🏾' => 'persoña ch’a fa OK: carnaxon assæ scua',
    '🙆🏿' => 'persoña ch’a fa OK: carnaxon scua',
    '💁🏻' => 'persoña co-o parmo in sciù: carnaxon ciæa',
    '💁🏼' => 'persoña co-o parmo in sciù: carnaxon assæ ciæa',
    '💁🏽' => 'persoña co-o parmo in sciù: carnaxon cô d’öiva',
    '💁🏾' => 'persoña co-o parmo in sciù: carnaxon assæ scua',
    '💁🏿' => 'persoña co-o parmo in sciù: carnaxon scua',
    '🙋🏻' => 'persoña ch’a tia sciù a man: carnaxon ciæa',
    '🙋🏼' => 'persoña ch’a tia sciù a man: carnaxon assæ ciæa',
    '🙋🏽' => 'persoña ch’a tia sciù a man: carnaxon cô d’öiva',
    '🙋🏾' => 'persoña ch’a tia sciù a man: carnaxon assæ scua',
    '🙋🏿' => 'persoña ch’a tia sciù a man: carnaxon scua',
    '🧏🏻' => 'persoña sorda: carnaxon ciæa',
    '🧏🏼' => 'persoña sorda: carnaxon assæ ciæa',
    '🧏🏽' => 'persoña sorda: carnaxon cô d’öiva',
    '🧏🏾' => 'persoña sorda: carnaxon assæ scua',
    '🧏🏿' => 'persoña sorda: carnaxon scua',
    '🙇🏻' => 'persoña ch’a fâ scoaccin: carnaxon ciæa',
    '🙇🏼' => 'persoña ch’a fâ scoaccin: carnaxon assæ ciæa',
    '🙇🏽' => 'persoña ch’a fâ scoaccin: carnaxon cô d’öiva',
    '🙇🏾' => 'persoña ch’a fâ scoaccin: carnaxon assæ scua',
    '🙇🏿' => 'persoña ch’a fâ scoaccin: carnaxon scua',
    '🤦🏻' => 'persoña esasperâ: carnaxon ciæa',
    '🤦🏼' => 'persoña esasperâ: carnaxon assæ ciæa',
    '🤦🏽' => 'persoña esasperâ: carnaxon cô d’öiva',
    '🤦🏾' => 'persoña esasperâ: carnaxon assæ scua',
    '🤦🏿' => 'persoña esasperâ: carnaxon scua',
    '🤷🏻' => 'persoña ch’a strenze e spalle: carnaxon ciæa',
    '🤷🏼' => 'persoña ch’a strenze e spalle: carnaxon assæ ciæa',
    '🤷🏽' => 'persoña ch’a strenze e spalle: carnaxon cô d’öiva',
    '🤷🏾' => 'persoña ch’a strenze e spalle: carnaxon assæ scua',
    '🤷🏿' => 'persoña ch’a strenze e spalle: carnaxon scua',
    '👮🏻' => 'poliçiòtto: carnaxon ciæa',
    '👮🏼' => 'poliçiòtto: carnaxon assæ ciæa',
    '👮🏽' => 'poliçiòtto: carnaxon cô d’öiva',
    '👮🏾' => 'poliçiòtto: carnaxon assæ scua',
    '👮🏿' => 'poliçiòtto: carnaxon scua',
    '🕵🏻' => 'investigatô: carnaxon ciæa',
    '🕵🏼' => 'investigatô: carnaxon assæ ciæa',
    '🕵🏽' => 'investigatô: carnaxon cô d’öiva',
    '🕵🏾' => 'investigatô: carnaxon assæ scua',
    '🕵🏿' => 'investigatô: carnaxon scua',
    '💂🏻' => 'guardia: carnaxon ciæa',
    '💂🏼' => 'guardia: carnaxon assæ ciæa',
    '💂🏽' => 'guardia: carnaxon cô d’öiva',
    '💂🏾' => 'guardia: carnaxon assæ scua',
    '💂🏿' => 'guardia: carnaxon scua',
    '🥷🏻' => 'ninja: carnaxon ciæa',
    '🥷🏼' => 'ninja: carnaxon assæ ciæa',
    '🥷🏽' => 'ninja: carnaxon cô d’öiva',
    '🥷🏾' => 'ninja: carnaxon assæ scua',
    '🥷🏿' => 'ninja: carnaxon scua',
    '👷🏻' => 'massacan: carnaxon ciæa',
    '👷🏼' => 'massacan: carnaxon assæ ciæa',
    '👷🏽' => 'massacan: carnaxon cô d’öiva',
    '👷🏾' => 'massacan: carnaxon assæ scua',
    '👷🏿' => 'massacan: carnaxon scua',
    '🫅🏻' => 'persoña co-a coroña: carnaxon ciæa',
    '🫅🏼' => 'persoña co-a coroña: carnaxon assæ ciæa',
    '🫅🏽' => 'persoña co-a coroña: carnaxon cô d’öiva',
    '🫅🏾' => 'persoña co-a coroña: carnaxon assæ scua',
    '🫅🏿' => 'persoña co-a coroña: carnaxon scua',
    '🤴🏻' => 'prinçipe: carnaxon ciæa',
    '🤴🏼' => 'prinçipe: carnaxon assæ ciæa',
    '🤴🏽' => 'prinçipe: carnaxon cô d’öiva',
    '🤴🏾' => 'prinçipe: carnaxon assæ scua',
    '🤴🏿' => 'prinçipe: carnaxon scua',
    '👸🏻' => 'prinçipessa: carnaxon ciæa',
    '👸🏼' => 'prinçipessa: carnaxon assæ ciæa',
    '👸🏽' => 'prinçipessa: carnaxon cô d’öiva',
    '👸🏾' => 'prinçipessa: carnaxon assæ scua',
    '👸🏿' => 'prinçipessa: carnaxon scua',
    '👳🏻' => 'persoña co-o turbante: carnaxon ciæa',
    '👳🏼' => 'persoña co-o turbante: carnaxon assæ ciæa',
    '👳🏽' => 'persoña co-o turbante: carnaxon cô d’öiva',
    '👳🏾' => 'persoña co-o turbante: carnaxon assæ scua',
    '👳🏿' => 'persoña co-o turbante: carnaxon scua',
    '👲🏻' => 'persoña con copolin: carnaxon ciæa',
    '👲🏼' => 'persoña con copolin: carnaxon assæ ciæa',
    '👲🏽' => 'persoña con copolin: carnaxon cô d’öiva',
    '👲🏾' => 'persoña con copolin: carnaxon assæ scua',
    '👲🏿' => 'persoña con copolin: carnaxon scua',
    '🧕🏻' => 'dònna co-o vello: carnaxon ciæa',
    '🧕🏼' => 'dònna co-o vello: carnaxon assæ ciæa',
    '🧕🏽' => 'dònna co-o vello: carnaxon cô d’öiva',
    '🧕🏾' => 'dònna co-o vello: carnaxon assæ scua',
    '🧕🏿' => 'dònna co-o vello: carnaxon scua',
    '🤵🏻' => 'persoña in smoking: carnaxon ciæa',
    '🤵🏼' => 'persoña in smoking: carnaxon assæ ciæa',
    '🤵🏽' => 'persoña in smoking: carnaxon cô d’öiva',
    '🤵🏾' => 'persoña in smoking: carnaxon assæ scua',
    '🤵🏿' => 'persoña in smoking: carnaxon scua',
    '👰🏻' => 'persoña co-o vello: carnaxon ciæa',
    '👰🏼' => 'persoña co-o vello: carnaxon assæ ciæa',
    '👰🏽' => 'persoña co-o vello: carnaxon cô d’öiva',
    '👰🏾' => 'persoña co-o vello: carnaxon assæ scua',
    '👰🏿' => 'persoña co-o vello: carnaxon scua',
    '🤰🏻' => 'dònna gräia: carnaxon ciæa',
    '🤰🏼' => 'dònna gräia: carnaxon assæ ciæa',
    '🤰🏽' => 'dònna gräia: carnaxon cô d’öiva',
    '🤰🏾' => 'dònna gräia: carnaxon assæ scua',
    '🤰🏿' => 'dònna gräia: carnaxon scua',
    '🫃🏻' => 'òmmo gräio: carnaxon ciæa',
    '🫃🏼' => 'òmmo gräio: carnaxon assæ ciæa',
    '🫃🏽' => 'òmmo gräio: carnaxon cô d’öiva',
    '🫃🏾' => 'òmmo gräio: carnaxon assæ scua',
    '🫃🏿' => 'òmmo gräio: carnaxon scua',
    '🫄🏻' => 'persoña gräia: carnaxon ciæa',
    '🫄🏼' => 'persoña gräia: carnaxon assæ ciæa',
    '🫄🏽' => 'persoña gräia: carnaxon cô d’öiva',
    '🫄🏾' => 'persoña gräia: carnaxon assæ scua',
    '🫄🏿' => 'persoña gräia: carnaxon scua',
    '🤱🏻' => 'dâ o læte: carnaxon ciæa',
    '🤱🏼' => 'dâ o læte: carnaxon assæ ciæa',
    '🤱🏽' => 'dâ o læte: carnaxon cô d’öiva',
    '🤱🏾' => 'dâ o læte: carnaxon assæ scua',
    '🤱🏿' => 'dâ o læte: carnaxon scua',
    '👼🏻' => 'angeo figgeu: carnaxon ciæa',
    '👼🏼' => 'angeo figgeu: carnaxon assæ ciæa',
    '👼🏽' => 'angeo figgeu: carnaxon cô d’öiva',
    '👼🏾' => 'angeo figgeu: carnaxon assæ scua',
    '👼🏿' => 'angeo figgeu: carnaxon scua',
    '🎅🏻' => 'Papà Dënâ: carnaxon ciæa',
    '🎅🏼' => 'Papà Dënâ: carnaxon assæ ciæa',
    '🎅🏽' => 'Papà Dënâ: carnaxon cô d’öiva',
    '🎅🏾' => 'Papà Dënâ: carnaxon assæ scua',
    '🎅🏿' => 'Papà Dënâ: carnaxon scua',
    '🤶🏻' => 'Mamà Dënâ: carnaxon ciæa',
    '🤶🏼' => 'Mamà Dënâ: carnaxon assæ ciæa',
    '🤶🏽' => 'Mamà Dënâ: carnaxon cô d’öiva',
    '🤶🏾' => 'Mamà Dënâ: carnaxon assæ scua',
    '🤶🏿' => 'Mamà Dënâ: carnaxon scua',
    '🦸🏻' => 'supereröe: carnaxon ciæa',
    '🦸🏼' => 'supereröe: carnaxon assæ ciæa',
    '🦸🏽' => 'supereröe: carnaxon cô d’öiva',
    '🦸🏾' => 'supereröe: carnaxon assæ scua',
    '🦸🏿' => 'supereröe: carnaxon scua',
    '🦹🏻' => 'supernemigo: carnaxon ciæa',
    '🦹🏼' => 'supernemigo: carnaxon assæ ciæa',
    '🦹🏽' => 'supernemigo: carnaxon cô d’öiva',
    '🦹🏾' => 'supernemigo: carnaxon assæ scua',
    '🦹🏿' => 'supernemigo: carnaxon scua',
    '🧙🏻' => 'mago: carnaxon ciæa',
    '🧙🏼' => 'mago: carnaxon assæ ciæa',
    '🧙🏽' => 'mago: carnaxon cô d’öiva',
    '🧙🏾' => 'mago: carnaxon assæ scua',
    '🧙🏿' => 'mago: carnaxon scua',
    '🧚🏻' => 'foæ: carnaxon ciæa',
    '🧚🏼' => 'foæ: carnaxon assæ ciæa',
    '🧚🏽' => 'foæ: carnaxon cô d’öiva',
    '🧚🏾' => 'foæ: carnaxon assæ scua',
    '🧚🏿' => 'foæ: carnaxon scua',
    '🧛🏻' => 'vampiro: carnaxon ciæa',
    '🧛🏼' => 'vampiro: carnaxon assæ ciæa',
    '🧛🏽' => 'vampiro: carnaxon cô d’öiva',
    '🧛🏾' => 'vampiro: carnaxon assæ scua',
    '🧛🏿' => 'vampiro: carnaxon scua',
    '🧜🏻' => 'triton: carnaxon ciæa',
    '🧜🏼' => 'triton: carnaxon assæ ciæa',
    '🧜🏽' => 'triton: carnaxon cô d’öiva',
    '🧜🏾' => 'triton: carnaxon assæ scua',
    '🧜🏿' => 'triton: carnaxon scua',
    '🧝🏻' => 'elfo: carnaxon ciæa',
    '🧝🏼' => 'elfo: carnaxon assæ ciæa',
    '🧝🏽' => 'elfo: carnaxon cô d’öiva',
    '🧝🏾' => 'elfo: carnaxon assæ scua',
    '🧝🏿' => 'elfo: carnaxon scua',
    '💆🏻' => 'persoña ch’a l’é massaggiâ: carnaxon ciæa',
    '💆🏼' => 'persoña ch’a l’é massaggiâ: carnaxon assæ ciæa',
    '💆🏽' => 'persoña ch’a l’é massaggiâ: carnaxon cô d’öiva',
    '💆🏾' => 'persoña ch’a l’é massaggiâ: carnaxon assæ scua',
    '💆🏿' => 'persoña ch’a l’é massaggiâ: carnaxon scua',
    '💇🏻' => 'persoña che ghe taggian i cavelli: carnaxon ciæa',
    '💇🏼' => 'persoña che ghe taggian i cavelli: carnaxon assæ ciæa',
    '💇🏽' => 'persoña che ghe taggian i cavelli: carnaxon cô d’öiva',
    '💇🏾' => 'persoña che ghe taggian i cavelli: carnaxon assæ scua',
    '💇🏿' => 'persoña che ghe taggian i cavelli: carnaxon scua',
    '🚶🏻' => 'persoña ch’a cammiña: carnaxon ciæa',
    '🚶🏼' => 'persoña ch’a cammiña: carnaxon assæ ciæa',
    '🚶🏽' => 'persoña ch’a cammiña: carnaxon cô d’öiva',
    '🚶🏾' => 'persoña ch’a cammiña: carnaxon assæ scua',
    '🚶🏿' => 'persoña ch’a cammiña: carnaxon scua',
    '🧍🏻' => 'persoña in pê: carnaxon ciæa',
    '🧍🏼' => 'persoña in pê: carnaxon assæ ciæa',
    '🧍🏽' => 'persoña in pê: carnaxon cô d’öiva',
    '🧍🏾' => 'persoña in pê: carnaxon assæ scua',
    '🧍🏿' => 'persoña in pê: carnaxon scua',
    '🧎🏻' => 'persoña in zenoggion: carnaxon ciæa',
    '🧎🏼' => 'persoña in zenoggion: carnaxon assæ ciæa',
    '🧎🏽' => 'persoña in zenoggion: carnaxon cô d’öiva',
    '🧎🏾' => 'persoña in zenoggion: carnaxon assæ scua',
    '🧎🏿' => 'persoña in zenoggion: carnaxon scua',
    '🏃🏻' => 'persoña ch’a core: carnaxon ciæa',
    '🏃🏼' => 'persoña ch’a core: carnaxon assæ ciæa',
    '🏃🏽' => 'persoña ch’a core: carnaxon cô d’öiva',
    '🏃🏾' => 'persoña ch’a core: carnaxon assæ scua',
    '🏃🏿' => 'persoña ch’a core: carnaxon scua',
    '💃🏻' => 'dònna ch’a balla: carnaxon ciæa',
    '💃🏼' => 'dònna ch’a balla: carnaxon assæ ciæa',
    '💃🏽' => 'dònna ch’a balla: carnaxon cô d’öiva',
    '💃🏾' => 'dònna ch’a balla: carnaxon assæ scua',
    '💃🏿' => 'dònna ch’a balla: carnaxon scua',
    '🕺🏻' => 'òmmo ch’o balla: carnaxon ciæa',
    '🕺🏼' => 'òmmo ch’o balla: carnaxon assæ ciæa',
    '🕺🏽' => 'òmmo ch’o balla: carnaxon cô d’öiva',
    '🕺🏾' => 'òmmo ch’o balla: carnaxon assæ scua',
    '🕺🏿' => 'òmmo ch’o balla: carnaxon scua',
    '🕴🏻' => 'persoña co-o vestî elegante ch’a levita: carnaxon ciæa',
    '🕴🏼' => 'persoña co-o vestî elegante ch’a levita: carnaxon assæ ciæa',
    '🕴🏽' => 'persoña co-o vestî elegante ch’a levita: carnaxon cô d’öiva',
    '🕴🏾' => 'persoña co-o vestî elegante ch’a levita: carnaxon assæ scua',
    '🕴🏿' => 'persoña co-o vestî elegante ch’a levita: carnaxon scua',
    '👯🏻' => 'persoñe co-e oege da coniggio: carnaxon ciæa',
    '👯🏼' => 'persoñe co-e oege da coniggio: carnaxon assæ ciæa',
    '👯🏽' => 'persoñe co-e oege da coniggio: carnaxon cô d’öiva',
    '👯🏾' => 'persoñe co-e oege da coniggio: carnaxon assæ scua',
    '👯🏿' => 'persoñe co-e oege da coniggio: carnaxon scua',
    '🧖🏻' => 'persoña inte unna stansia piña de vapô: carnaxon ciæa',
    '🧖🏼' => 'persoña inte unna stansia piña de vapô: carnaxon assæ ciæa',
    '🧖🏽' => 'persoña inte unna stansia piña de vapô: carnaxon cô d’öiva',
    '🧖🏾' => 'persoña inte unna stansia piña de vapô: carnaxon assæ scua',
    '🧖🏿' => 'persoña inte unna stansia piña de vapô: carnaxon scua',
    '🧗🏻' => 'persoña ch’a s’arrampiña: carnaxon ciæa',
    '🧗🏼' => 'persoña ch’a s’arrampiña: carnaxon assæ ciæa',
    '🧗🏽' => 'persoña ch’a s’arrampiña: carnaxon cô d’öiva',
    '🧗🏾' => 'persoña ch’a s’arrampiña: carnaxon assæ scua',
    '🧗🏿' => 'persoña ch’a s’arrampiña: carnaxon scua',
    '🏇🏻' => 'ippica: carnaxon ciæa',
    '🏇🏼' => 'ippica: carnaxon assæ ciæa',
    '🏇🏽' => 'ippica: carnaxon cô d’öiva',
    '🏇🏾' => 'ippica: carnaxon assæ scua',
    '🏇🏿' => 'ippica: carnaxon scua',
    '🏂🏻' => 'persoña in sciô snowboard: carnaxon ciæa',
    '🏂🏼' => 'persoña in sciô snowboard: carnaxon assæ ciæa',
    '🏂🏽' => 'persoña in sciô snowboard: carnaxon cô d’öiva',
    '🏂🏾' => 'persoña in sciô snowboard: carnaxon assæ scua',
    '🏂🏿' => 'persoña in sciô snowboard: carnaxon scua',
    '🏌🏻' => 'persoña ch’a zeuga à gòlf: carnaxon ciæa',
    '🏌🏼' => 'persoña ch’a zeuga à gòlf: carnaxon assæ ciæa',
    '🏌🏽' => 'persoña ch’a zeuga à gòlf: carnaxon cô d’öiva',
    '🏌🏾' => 'persoña ch’a zeuga à gòlf: carnaxon assæ scua',
    '🏌🏿' => 'persoña ch’a zeuga à gòlf: carnaxon scua',
    '🏄🏻' => 'persoña ch’a fa surf: carnaxon ciæa',
    '🏄🏼' => 'persoña ch’a fa surf: carnaxon assæ ciæa',
    '🏄🏽' => 'persoña ch’a fa surf: carnaxon cô d’öiva',
    '🏄🏾' => 'persoña ch’a fa surf: carnaxon assæ scua',
    '🏄🏿' => 'persoña ch’a fa surf: carnaxon scua',
    '🚣🏻' => 'persoña ch’a remma: carnaxon ciæa',
    '🚣🏼' => 'persoña ch’a remma: carnaxon assæ ciæa',
    '🚣🏽' => 'persoña ch’a remma: carnaxon cô d’öiva',
    '🚣🏾' => 'persoña ch’a remma: carnaxon assæ scua',
    '🚣🏿' => 'persoña ch’a remma: carnaxon scua',
    '🏊🏻' => 'persoña ch’a neua: carnaxon ciæa',
    '🏊🏼' => 'persoña ch’a neua: carnaxon assæ ciæa',
    '🏊🏽' => 'persoña ch’a neua: carnaxon cô d’öiva',
    '🏊🏾' => 'persoña ch’a neua: carnaxon assæ scua',
    '🏊🏿' => 'persoña ch’a neua: carnaxon scua',
    '⛹🏻' => 'persoña ch’a fa bottezzâ un ballon: carnaxon ciæa',
    '⛹🏼' => 'persoña ch’a fa bottezzâ un ballon: carnaxon assæ ciæa',
    '⛹🏽' => 'persoña ch’a fa bottezzâ un ballon: carnaxon cô d’öiva',
    '⛹🏾' => 'persoña ch’a fa bottezzâ un ballon: carnaxon assæ scua',
    '⛹🏿' => 'persoña ch’a fa bottezzâ un ballon: carnaxon scua',
    '🏋🏻' => 'persoña ch’a tia sciù i peixi: carnaxon ciæa',
    '🏋🏼' => 'persoña ch’a tia sciù i peixi: carnaxon assæ ciæa',
    '🏋🏽' => 'persoña ch’a tia sciù i peixi: carnaxon cô d’öiva',
    '🏋🏾' => 'persoña ch’a tia sciù i peixi: carnaxon assæ scua',
    '🏋🏿' => 'persoña ch’a tia sciù i peixi: carnaxon scua',
    '🚴🏻' => 'persoña ch’a va in biçicletta: carnaxon ciæa',
    '🚴🏼' => 'persoña ch’a va in biçicletta: carnaxon assæ ciæa',
    '🚴🏽' => 'persoña ch’a va in biçicletta: carnaxon cô d’öiva',
    '🚴🏾' => 'persoña ch’a va in biçicletta: carnaxon assæ scua',
    '🚴🏿' => 'persoña ch’a va in biçicletta: carnaxon scua',
    '🚵🏻' => 'persoña ch’a va in mountain bike: carnaxon ciæa',
    '🚵🏼' => 'persoña ch’a va in mountain bike: carnaxon assæ ciæa',
    '🚵🏽' => 'persoña ch’a va in mountain bike: carnaxon cô d’öiva',
    '🚵🏾' => 'persoña ch’a va in mountain bike: carnaxon assæ scua',
    '🚵🏿' => 'persoña ch’a va in mountain bike: carnaxon scua',
    '🤸🏻' => 'persoña ch’a fa a reua: carnaxon ciæa',
    '🤸🏼' => 'persoña ch’a fa a reua: carnaxon assæ ciæa',
    '🤸🏽' => 'persoña ch’a fa a reua: carnaxon cô d’öiva',
    '🤸🏾' => 'persoña ch’a fa a reua: carnaxon assæ scua',
    '🤸🏿' => 'persoña ch’a fa a reua: carnaxon scua',
    '🤼🏻' => 'persoñe che lòttan: carnaxon ciæa',
    '🤼🏼' => 'persoñe che lòttan: carnaxon assæ ciæa',
    '🤼🏽' => 'persoñe che lòttan: carnaxon cô d’öiva',
    '🤼🏾' => 'persoñe che lòttan: carnaxon assæ scua',
    '🤼🏿' => 'persoñe che lòttan: carnaxon scua',
    '🤽🏻' => 'persoña ch’a zeuga à waterpölo: carnaxon ciæa',
    '🤽🏼' => 'persoña ch’a zeuga à waterpölo: carnaxon assæ ciæa',
    '🤽🏽' => 'persoña ch’a zeuga à waterpölo: carnaxon cô d’öiva',
    '🤽🏾' => 'persoña ch’a zeuga à waterpölo: carnaxon assæ scua',
    '🤽🏿' => 'persoña ch’a zeuga à waterpölo: carnaxon scua',
    '🤾🏻' => 'persoña ch’a zeuga à pallaman: carnaxon ciæa',
    '🤾🏼' => 'persoña ch’a zeuga à pallaman: carnaxon assæ ciæa',
    '🤾🏽' => 'persoña ch’a zeuga à pallaman: carnaxon cô d’öiva',
    '🤾🏾' => 'persoña ch’a zeuga à pallaman: carnaxon assæ scua',
    '🤾🏿' => 'persoña ch’a zeuga à pallaman: carnaxon scua',
    '🤹🏻' => 'persoña ch’a fa i zeughi: carnaxon ciæa',
    '🤹🏼' => 'persoña ch’a fa i zeughi: carnaxon assæ ciæa',
    '🤹🏽' => 'persoña ch’a fa i zeughi: carnaxon cô d’öiva',
    '🤹🏾' => 'persoña ch’a fa i zeughi: carnaxon assæ scua',
    '🤹🏿' => 'persoña ch’a fa i zeughi: carnaxon scua',
    '🧘🏻' => 'persoña in sciâ poxiçion do löto: carnaxon ciæa',
    '🧘🏼' => 'persoña in sciâ poxiçion do löto: carnaxon assæ ciæa',
    '🧘🏽' => 'persoña in sciâ poxiçion do löto: carnaxon cô d’öiva',
    '🧘🏾' => 'persoña in sciâ poxiçion do löto: carnaxon assæ scua',
    '🧘🏿' => 'persoña in sciâ poxiçion do löto: carnaxon scua',
    '🛀🏻' => 'persoña ch’a se fâ un bagno: carnaxon ciæa',
    '🛀🏼' => 'persoña ch’a se fâ un bagno: carnaxon assæ ciæa',
    '🛀🏽' => 'persoña ch’a se fâ un bagno: carnaxon cô d’öiva',
    '🛀🏾' => 'persoña ch’a se fâ un bagno: carnaxon assæ scua',
    '🛀🏿' => 'persoña ch’a se fâ un bagno: carnaxon scua',
    '🛌🏻' => 'persoña in letto: carnaxon ciæa',
    '🛌🏼' => 'persoña in letto: carnaxon assæ ciæa',
    '🛌🏽' => 'persoña in letto: carnaxon cô d’öiva',
    '🛌🏾' => 'persoña in letto: carnaxon assæ scua',
    '🛌🏿' => 'persoña in letto: carnaxon scua',
    '👭🏻' => 'doe dònne che se tëgnan pe-a man: carnaxon ciæa',
    '👭🏼' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ ciæa',
    '👭🏽' => 'doe dònne che se tëgnan pe-a man: carnaxon cô d’öiva',
    '👭🏾' => 'doe dònne che se tëgnan pe-a man: carnaxon assæ scua',
    '👭🏿' => 'doe dònne che se tëgnan pe-a man: carnaxon scua',
    '👫🏻' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon ciæa',
    '👫🏼' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ ciæa',
    '👫🏽' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon cô d’öiva',
    '👫🏾' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon assæ scua',
    '👫🏿' => 'dònna e òmmo che se tëgnan pe-a man: carnaxon scua',
    '👬🏻' => 'doî òmmi che se tëgnan pe-a man: carnaxon ciæa',
    '👬🏼' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ ciæa',
    '👬🏽' => 'doî òmmi che se tëgnan pe-a man: carnaxon cô d’öiva',
    '👬🏾' => 'doî òmmi che se tëgnan pe-a man: carnaxon assæ scua',
    '👬🏿' => 'doî òmmi che se tëgnan pe-a man: carnaxon scua',
    '💏🏻' => 'baxo: carnaxon ciæa',
    '💏🏼' => 'baxo: carnaxon assæ ciæa',
    '💏🏽' => 'baxo: carnaxon cô d’öiva',
    '💏🏾' => 'baxo: carnaxon assæ scua',
    '💏🏿' => 'baxo: carnaxon scua',
    '💑🏻' => 'cobbia con cheucobbia co-o cheu: carnaxon ciæa',
    '💑🏼' => 'cobbia con cheucobbia co-o cheu: carnaxon assæ ciæa',
    '💑🏽' => 'cobbia con cheucobbia co-o cheu: carnaxon cô d’öiva',
    '💑🏾' => 'cobbia con cheucobbia co-o cheu: carnaxon assæ scua',
    '💑🏿' => 'cobbia con cheucobbia co-o cheu: carnaxon scua',
    '🇦🇨' => 'bandea: Isoa de l’Ascension',
    '🇦🇩' => 'bandea: Andòrra',
    '🇦🇪' => 'bandea: Emirati arabi unii',
    '🇦🇫' => 'bandea: Afghanistan',
    '🇦🇬' => 'bandea: Antigua e Barbuda',
    '🇦🇮' => 'bandea: Anguilla',
    '🇦🇱' => 'bandea: Arbania',
    '🇦🇲' => 'bandea: Ermenia',
    '🇦🇴' => 'bandea: Angola',
    '🇦🇶' => 'bandea: Antartide',
    '🇦🇷' => 'bandea: Argentiña',
    '🇦🇸' => 'bandea: Samoa americaña',
    '🇦🇹' => 'bandea: Austria',
    '🇦🇺' => 'bandea: Australia',
    '🇦🇼' => 'bandea: Aruba',
    '🇦🇽' => 'bandea: Isoe Åland',
    '🇦🇿' => 'bandea: Azerbaigian',
    '🇧🇦' => 'bandea: Bòsnia e Herzegòvina',
    '🇧🇧' => 'bandea: Barbados',
    '🇧🇩' => 'bandea: Bangladesh',
    '🇧🇪' => 'bandea: Belgio',
    '🇧🇫' => 'bandea: Burkina Faso',
    '🇧🇬' => 'bandea: Borgaia',
    '🇧🇭' => 'bandea: Bahrein',
    '🇧🇮' => 'bandea: Burundi',
    '🇧🇯' => 'bandea: Benin',
    '🇧🇱' => 'bandea: San Bertomê',
    '🇧🇲' => 'bandea: Bermuda',
    '🇧🇳' => 'bandea: Brunei',
    '🇧🇴' => 'bandea: Bolivia',
    '🇧🇶' => 'bandea: Caraibi olandeixi',
    '🇧🇷' => 'bandea: Braxî',
    '🇧🇸' => 'bandea: Bahamas',
    '🇧🇹' => 'bandea: Bhutan',
    '🇧🇻' => 'bandea: Isoa Bouvet',
    '🇧🇼' => 'bandea: Botswana',
    '🇧🇾' => 'bandea: Bieloruscia',
    '🇧🇿' => 'bandea: Belize',
    '🇨🇦' => 'bandea: Canadà',
    '🇨🇨' => 'bandea: Isoe Cocos (Keeling)',
    '🇨🇩' => 'bandea: Congo-Kinshasa',
    '🇨🇫' => 'bandea: Repubrica çentrafricaña',
    '🇨🇬' => 'bandea: Congo-Brazzaville',
    '🇨🇭' => 'bandea: Svissera',
    '🇨🇮' => 'bandea: Còsta d’Avöio',
    '🇨🇰' => 'bandea: Isoe Cook',
    '🇨🇱' => 'bandea: Cile',
    '🇨🇲' => 'bandea: Cameron',
    '🇨🇳' => 'bandea: Ciña',
    '🇨🇴' => 'bandea: Colombia',
    '🇨🇵' => 'bandea: Isoa de Clipperton',
    '🇨🇷' => 'bandea: Còsta Rica',
    '🇨🇺' => 'bandea: Cubba',
    '🇨🇻' => 'bandea: Cappo Verde',
    '🇨🇼' => 'bandea: Curaçao',
    '🇨🇽' => 'bandea: Isoa Christmas',
    '🇨🇾' => 'bandea: Çipri',
    '🇨🇿' => 'bandea: Cechia',
    '🇩🇪' => 'bandea: Germania',
    '🇩🇬' => 'bandea: Diego Garcia',
    '🇩🇯' => 'bandea: Djibouti',
    '🇩🇰' => 'bandea: Danimarca',
    '🇩🇲' => 'bandea: Dominica',
    '🇩🇴' => 'bandea: Repubrica dominicaña',
    '🇩🇿' => 'bandea: Algeria',
    '🇪🇦' => 'bandea: Çéuta e Melilla',
    '🇪🇨' => 'bandea: Ecuador',
    '🇪🇪' => 'bandea: Estònia',
    '🇪🇬' => 'bandea: Egitto',
    '🇪🇭' => 'bandea: Sahara de ponente',
    '🇪🇷' => 'bandea: Eritrea',
    '🇪🇸' => 'bandea: Spagna',
    '🇪🇹' => 'bandea: Etiòpia',
    '🇪🇺' => 'bandea: Union europea',
    '🇫🇮' => 'bandea: Finlandia',
    '🇫🇯' => 'bandea: Figi',
    '🇫🇰' => 'bandea: Isoe Malviñe',
    '🇫🇲' => 'bandea: Micronesia',
    '🇫🇴' => 'bandea: Isoe Fær Øer',
    '🇫🇷' => 'bandea: Fransa',
    '🇬🇦' => 'bandea: Gabon',
    '🇬🇧' => 'bandea: Regno Unio',
    '🇬🇩' => 'bandea: Granada',
    '🇬🇪' => 'bandea: Geòrgia',
    '🇬🇫' => 'bandea: Guyana franseise',
    '🇬🇬' => 'bandea: Guernsey',
    '🇬🇭' => 'bandea: Ghana',
    '🇬🇮' => 'bandea: Gibertâ',
    '🇬🇱' => 'bandea: Groenlandia',
    '🇬🇲' => 'bandea: Gambia',
    '🇬🇳' => 'bandea: Guinea',
    '🇬🇵' => 'bandea: Guadaluppa',
    '🇬🇶' => 'bandea: Guinea equatoiäle',
    '🇬🇷' => 'bandea: Greçia',
    '🇬🇸' => 'bandea: Geòrgia do Sud e Isoe Sandwich do Sud',
    '🇬🇹' => 'bandea: Guatemala',
    '🇬🇺' => 'bandea: Guam',
    '🇬🇼' => 'bandea: Guinea Bissau',
    '🇬🇾' => 'bandea: Guyana',
    '🇭🇰' => 'bandea: RAS de Hong Kong (Ciña)',
    '🇭🇲' => 'bandea: Isoe Heard e McDonald',
    '🇭🇳' => 'bandea: Honduras',
    '🇭🇷' => 'bandea: Croaçia',
    '🇭🇹' => 'bandea: Haiti',
    '🇭🇺' => 'bandea: Ongaia',
    '🇮🇨' => 'bandea: Isoe Canäie',
    '🇮🇩' => 'bandea: Indonesia',
    '🇮🇪' => 'bandea: Irlanda',
    '🇮🇱' => 'bandea: Israele',
    '🇮🇲' => 'bandea: Isoa de Man',
    '🇮🇳' => 'bandea: India',
    '🇮🇴' => 'bandea: Tære britanniche de l’oçeano Indian',
    '🇮🇶' => 'bandea: Iraq',
    '🇮🇷' => 'bandea: Iran',
    '🇮🇸' => 'bandea: Islanda',
    '🇮🇹' => 'bandea: Italia',
    '🇯🇪' => 'bandea: Jersey',
    '🇯🇲' => 'bandea: Giamaica',
    '🇯🇴' => 'bandea: Giordania',
    '🇯🇵' => 'bandea: Giappon',
    '🇰🇪' => 'bandea: Kenya',
    '🇰🇬' => 'bandea: Kirghizistan',
    '🇰🇭' => 'bandea: Cambòggia',
    '🇰🇮' => 'bandea: Kiribati',
    '🇰🇲' => 'bandea: Comöre',
    '🇰🇳' => 'bandea: San Cristòffa e Nevis',
    '🇰🇵' => 'bandea: Corea do Nòrd',
    '🇰🇷' => 'bandea: Corea do Sud',
    '🇰🇼' => 'bandea: Kuwait',
    '🇰🇾' => 'bandea: Isoe Cayman',
    '🇰🇿' => 'bandea: Kazakistan',
    '🇱🇦' => 'bandea: Laos',
    '🇱🇧' => 'bandea: Libano',
    '🇱🇨' => 'bandea: Santa Luçia',
    '🇱🇮' => 'bandea: Liechtenstein',
    '🇱🇰' => 'bandea: Sri Lanka',
    '🇱🇷' => 'bandea: Liberia',
    '🇱🇸' => 'bandea: Lesotho',
    '🇱🇹' => 'bandea: Lituania',
    '🇱🇺' => 'bandea: Luxemburgo',
    '🇱🇻' => 'bandea: Lettònia',
    '🇱🇾' => 'bandea: Libia',
    '🇲🇦' => 'bandea: Maròcco',
    '🇲🇨' => 'bandea: Monego',
    '🇲🇩' => 'bandea: Moldavia',
    '🇲🇪' => 'bandea: Monteneigro',
    '🇲🇫' => 'bandea: San Martin',
    '🇲🇬' => 'bandea: Madagascar',
    '🇲🇭' => 'bandea: Isoe Marshall',
    '🇲🇰' => 'bandea: Maçedònia do Nòrd',
    '🇲🇱' => 'bandea: Mali',
    '🇲🇲' => 'bandea: Myanmar (Birmania)',
    '🇲🇳' => 'bandea: Mongòlia',
    '🇲🇴' => 'bandea: RAS de Macao',
    '🇲🇵' => 'bandea: Isoe Mariañe de settentrion',
    '🇲🇶' => 'bandea: Martinica',
    '🇲🇷' => 'bandea: Mauritania',
    '🇲🇸' => 'bandea: Montserrat',
    '🇲🇹' => 'bandea: Malta',
    '🇲🇺' => 'bandea: Mauritius',
    '🇲🇻' => 'bandea: Maldive',
    '🇲🇼' => 'bandea: Malawi',
    '🇲🇽' => 'bandea: Mescico',
    '🇲🇾' => 'bandea: Malaysia',
    '🇲🇿' => 'bandea: Mozambico',
    '🇳🇦' => 'bandea: Namibia',
    '🇳🇨' => 'bandea: Neuva Caledònia',
    '🇳🇪' => 'bandea: Niger',
    '🇳🇫' => 'bandea: Isoa Norfolk',
    '🇳🇬' => 'bandea: Nigeria',
    '🇳🇮' => 'bandea: Nicaragua',
    '🇳🇱' => 'bandea: Paixi Basci',
    '🇳🇴' => 'bandea: Norveggia',
    '🇳🇵' => 'bandea: Nepal',
    '🇳🇷' => 'bandea: Nauru',
    '🇳🇺' => 'bandea: Niue',
    '🇳🇿' => 'bandea: Neuva Zelanda',
    '🇴🇲' => 'bandea: Òman',
    '🇵🇦' => 'bandea: Panama',
    '🇵🇪' => 'bandea: Perù',
    '🇵🇫' => 'bandea: Polinesia fraseise',
    '🇵🇬' => 'bandea: Papua Neuva Guinea',
    '🇵🇭' => 'bandea: Filipiñe',
    '🇵🇰' => 'bandea: Pakistan',
    '🇵🇱' => 'bandea: Polònia',
    '🇵🇲' => 'bandea: San Pê e Miquelon',
    '🇵🇳' => 'bandea: Isoe Pitcairn',
    '🇵🇷' => 'bandea: Puerto Rico',
    '🇵🇸' => 'bandea: Tære palestineixi',
    '🇵🇹' => 'bandea: Portugâ',
    '🇵🇼' => 'bandea: Palau',
    '🇵🇾' => 'bandea: Paraguay',
    '🇶🇦' => 'bandea: Qatar',
    '🇷🇪' => 'bandea: Réunion',
    '🇷🇴' => 'bandea: Romania',
    '🇷🇸' => 'bandea: Serbia',
    '🇷🇺' => 'bandea: Ruscia',
    '🇷🇼' => 'bandea: Rwanda',
    '🇸🇦' => 'bandea: Arabia saudia',
    '🇸🇧' => 'bandea: Isoe Salomon',
    '🇸🇨' => 'bandea: Seychelles',
    '🇸🇩' => 'bandea: Sudan',
    '🇸🇪' => 'bandea: Sveçia',
    '🇸🇬' => 'bandea: Scingapô',
    '🇸🇭' => 'bandea: Sant’Elena',
    '🇸🇮' => 'bandea: Slovenia',
    '🇸🇯' => 'bandea: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandea: Slovacchia',
    '🇸🇱' => 'bandea: Sierra Leone',
    '🇸🇲' => 'bandea: San Marin',
    '🇸🇳' => 'bandea: Senegal',
    '🇸🇴' => 'bandea: Somalia',
    '🇸🇷' => 'bandea: Suriname',
    '🇸🇸' => 'bandea: Sudan do Sud',
    '🇸🇹' => 'bandea: Sao Tomé e Prinçipe',
    '🇸🇻' => 'bandea: El Salvador',
    '🇸🇽' => 'bandea: Sint Maarten',
    '🇸🇾' => 'bandea: Sciria',
    '🇸🇿' => 'bandea: Eswatini',
    '🇹🇦' => 'bandea: Tristan da Cunha',
    '🇹🇨' => 'bandea: Isoe Turks e Caicos',
    '🇹🇩' => 'bandea: Chad',
    '🇹🇫' => 'bandea: Tære australe franseixi',
    '🇹🇬' => 'bandea: Tögo',
    '🇹🇭' => 'bandea: Tailandia',
    '🇹🇯' => 'bandea: Tagikistan',
    '🇹🇰' => 'bandea: Tokelau',
    '🇹🇱' => 'bandea: Timor Est',
    '🇹🇲' => 'bandea: Turkmenistan',
    '🇹🇳' => 'bandea: Tunexia',
    '🇹🇴' => 'bandea: Tonga',
    '🇹🇷' => 'bandea: Turchia',
    '🇹🇹' => 'bandea: Trinidad e Tobago',
    '🇹🇻' => 'bandea: Tuvalu',
    '🇹🇼' => 'bandea: Taiwan',
    '🇹🇿' => 'bandea: Tanzania',
    '🇺🇦' => 'bandea: Ucraiña',
    '🇺🇬' => 'bandea: Uganda',
    '🇺🇲' => 'bandea: Isoe lontañe di SUA',
    '🇺🇳' => 'bandea: Naçioin Unie',
    '🇺🇸' => 'bandea: Stati Unii',
    '🇺🇾' => 'bandea: Uruguay',
    '🇺🇿' => 'bandea: Uzbekistan',
    '🇻🇦' => 'bandea: Çittæ do Vatican',
    '🇻🇨' => 'bandea: San Viçenso e e Granadiñe',
    '🇻🇪' => 'bandea: Venessuela',
    '🇻🇬' => 'bandea: Isoe Vergine britanniche',
    '🇻🇮' => 'bandea: Isoe Vergine di Stati Unii',
    '🇻🇳' => 'bandea: Vietnam',
    '🇻🇺' => 'bandea: Vanuatu',
    '🇼🇫' => 'bandea: Wallis e Futuna',
    '🇼🇸' => 'bandea: Samoa',
    '🇽🇰' => 'bandea: Kòsovo',
    '🇾🇪' => 'bandea: Yemen',
    '🇾🇹' => 'bandea: Maiòtta',
    '🇿🇦' => 'bandea: Sudafrica',
    '🇿🇲' => 'bandea: Zambia',
    '🇿🇼' => 'bandea: Zimbabwe',
    '🔟' => 'tasto: 10',
    '🏻' => 'carnaxon ciæa',
    '🏼' => 'carnaxon assæ ciæa',
    '🏽' => 'carnaxon cô d’öiva',
    '🏾' => 'carnaxon assæ scua',
    '🏿' => 'carnaxon scua',
    '😀' => 'morin ch’o rie fòrte',
    '😃' => 'morin ch’o rie fòrte co-i euggi averti',
    '😄' => 'morin ch’o rie fòrte co-i euggi contenti',
    '😁' => 'morin sciallou co-i euggi contenti',
    '😆' => 'morin ch’o rie fòrte co-i euggi serræ',
    '😅' => 'morin ch’o rie fòrte con stissa de suo',
    '🤣' => 'scciuppon de rie',
    '😂' => 'morin ch’o cianze da-a contentessa',
    '🙂' => 'morin co-o fattoriso',
    '🙃' => 'morin imböso',
    '🫠' => 'morin ch’o se deslengua',
    '😉' => 'morin ch’o sciacca de l’euggio',
    '😊' => 'morin ch’o rie co-i euggi contenti',
    '😇' => 'morin ch’o rie con l’aureola',
    '🥰' => 'morin co-o fattoriso e cheu',
    '😍' => 'morin co-o fattoriso e euggi à cheu',
    '🤩' => 'morin co-i euggi che fan stelle',
    '😘' => 'morin ch’o manda un baxo',
    '😗' => 'morin ch’o baxa',
    '☺' => 'morin ch’o rie',
    '😚' => 'morin ch’o baxa co-i euggi serræ',
    '😙' => 'morin ch’o baxa co-i euggi contenti',
    '🥲' => 'morin ch’o rie con lagrima',
    '😋' => 'morin ch’o se perlecca',
    '😛' => 'morin co-a lengua de feua',
    '😜' => 'morin ch’o sciacca de l’euggio e lengua',
    '🤪' => 'morin matto',
    '😝' => 'morin co-i euggi serræ e a lengua de feua',
    '🤑' => 'morin co-a bocca de dinæ',
    '🤗' => 'morin ch’o l’abbrassa',
    '🤭' => 'morin ch’o se creuve a bocca',
    '🫢' => 'morin co-i euggi averti e a bocca coverta',
    '🫣' => 'morin ch’o l’aggueita tramezo a-e die',
    '🤫' => 'morin ch’o l’attaxenta',
    '🤔' => 'morin conçentrou',
    '🫡' => 'morin ch’o salua',
    '🤐' => 'morin co-a bocca à çernea',
    '🤨' => 'morin co-e çegge aggrondæ',
    '😐' => 'morin néutro',
    '😑' => 'morin sensa esprescion',
    '😶' => 'morin sensa bocca',
    '🫥' => 'morin trattezzou',
    '😏' => 'morin co-o fattoriso asperto',
    '😒' => 'morin ascidiou',
    '🙄' => 'morin co-i euggi verso l’erto',
    '😬' => 'morin con grimassa',
    '🤥' => 'morin boxardo',
    '🫨' => 'morin ch’o tremma',
    '😌' => 'morin reparpou',
    '😔' => 'morin pensamentoso',
    '😪' => 'morin dormiggioso',
    '🤤' => 'morin co-a bava',
    '😴' => 'morin addormio',
    '😷' => 'morin co-a mascariña',
    '🤒' => 'morin co-o termòmetro',
    '🤕' => 'morin co-a testa imbindâ',
    '🤢' => 'morin angosciou',
    '🤮' => 'morin ch’o rësa',
    '🤧' => 'morin ch’o stranua',
    '🥵' => 'morin ch’o l’à cado',
    '🥶' => 'morin giassou',
    '🥴' => 'morin bambordio',
    '😵' => 'morin invexendou',
    '🤯' => 'testa ch’a scciuppa',
    '🤠' => 'morin co-o cappello da cowboy',
    '🥳' => 'morin ch’o festezza',
    '🥸' => 'morin stravestio',
    '😎' => 'morin ch’o rie co-i speggetti neigri',
    '🤓' => 'morin studioso',
    '🧐' => 'morin co-o monòcolo',
    '😕' => 'morin confuso',
    '🫤' => 'morin co-a bocca diagonale',
    '😟' => 'morin preoccupou',
    '🙁' => 'morin un pittin ammagonou',
    '☹' => 'morin ammagonou',
    '😮' => 'morin co-a bocca averta',
    '😯' => 'morin sorpreiso',
    '😲' => 'morin mäveggiou',
    '😳' => 'morin imbarassou',
    '🥺' => 'morin ch’o suprica',
    '🥹' => 'morin ch’o trattëgne e lagrime',
    '😦' => 'morin inmoronou co-a bocca averta',
    '😧' => 'morin anscietoso',
    '😨' => 'morin inspaximou',
    '😰' => 'morin anscioso con stissa de suo',
    '😥' => 'morin deluso ma da-o cheu arrecoviou',
    '😢' => 'morin ch’o cianze',
    '😭' => 'morin ch’o cianze fòrte',
    '😱' => 'morin ch’o cria da-o terrô',
    '😖' => 'morin perplesso',
    '😣' => 'morin ch’o persciste',
    '😞' => 'morin deluso',
    '😓' => 'morin ammagunou con stissa de suo',
    '😩' => 'morin stracco',
    '😫' => 'morin stanco',
    '🥱' => 'morin ch’o bägia',
    '😤' => 'morin ch’o boffa',
    '😡' => 'morin arraggiou',
    '😠' => 'morin rouso',
    '🤬' => 'morin co-i scimboli in sciâ bocca',
    '😈' => 'morin ch’o rie co-e còrne',
    '👿' => 'morin rouso co-e còrne',
    '💀' => 'testa de mòrto',
    '☠' => 'testa de mòrto con òsse incroxæ',
    '💩' => 'cacà',
    '🤡' => 'morin da paggiasso',
    '👹' => 'òrco',
    '👺' => 'barban',
    '👻' => 'fantaxima',
    '👽' => 'alieno',
    '👾' => 'mostro alieno',
    '🤖' => 'robot',
    '😺' => 'gatto ch’o rie fòrte',
    '😸' => 'gatto ch’o rie fòrte co-i euggi contenti',
    '😹' => 'gatto ch’o cianze da-a contentessa',
    '😻' => 'gatto ch’o rie co-i euggi à cheu',
    '😼' => 'gatto co-o fattoriso sarcastico',
    '😽' => 'gatto ch’o baxa',
    '🙀' => 'gatto abbötio',
    '😿' => 'gatto ch’o cianze',
    '😾' => 'gatto inmoronou',
    '🙈' => 'no veddo',
    '🙉' => 'no sento',
    '🙊' => 'no parlo',
    '💌' => 'lettia d’amô',
    '💘' => 'cheu co-a freccia',
    '💝' => 'cheu con frexetto',
    '💖' => 'cheu ch’o luxe',
    '💗' => 'cheu ch’o cresce',
    '💓' => 'cheu ch’o batte',
    '💞' => 'cheu che gian',
    '💕' => 'doî cheu',
    '💟' => 'addobbo con cheu',
    '❣' => 'ponto d’esclamaçion à cheu',
    '💔' => 'cheu rotto',
    '❤' => 'cheu rosso',
    '🩷' => 'cheu reusa',
    '🧡' => 'cheu cô de çetron',
    '💛' => 'cheu giano',
    '💚' => 'cheu verde',
    '💙' => 'cheu bleu',
    '🩵' => 'cheu bleuçê',
    '💜' => 'cheu moelo',
    '🤎' => 'cheu marròn',
    '🖤' => 'cheu neigro',
    '🩶' => 'cheu grixo',
    '🤍' => 'cheu gianco',
    '💋' => 'segno de baxo',
    '💯' => 'çento ponti',
    '💢' => 'scimbolo da raggia',
    '💥' => 'collixon',
    '💫' => 'stella con scia',
    '💦' => 'stisse de suo',
    '💨' => 'nuvia de pua',
    '🕳' => 'beuggio',
    '💬' => 'ballon de discorso',
    '🗨' => 'ballon de discorso a-a manciña',
    '🗯' => 'ballon ch’o l’esprimme raggia',
    '💭' => 'ballon de pensceo',
    '💤' => 'dormî',
    '👋' => 'man ch’a salua',
    '🤚' => 'dorso da man arsou',
    '🖐' => 'man averta',
    '✋' => 'man arsâ',
    '🖖' => 'saluo vulcanian',
    '🫱' => 'man a-a drita',
    '🫲' => 'man a-a manciña',
    '🫳' => 'man co-o parmo in zu',
    '🫴' => 'man co-o parmo in sciù',
    '🫷' => 'man ch’a sponcia a-a manciña',
    '🫸' => 'man ch’a sponcia a-a drita',
    '👌' => 'man ch’a fa OK',
    '🤌' => 'man à pigna',
    '🤏' => 'man ch’a spellinsega',
    '✌' => 'gesto de vittöia',
    '🤞' => 'die incroxæ',
    '🫰' => 'man con dio longâ e gròsso incroxæ',
    '🤟' => 'gesto t’ammo',
    '🤘' => 'gesto de còrne',
    '🤙' => 'gesto ciammime',
    '👈' => 'dorso da man ch’a mostra a-a manciña',
    '👉' => 'dorso da man ch’a mostra a-a drita',
    '👆' => 'dorso da man ch’a mostra in sciù',
    '🖕' => 'dio de mezo',
    '👇' => 'dorso da man ch’a mostra in zu',
    '☝' => 'dio longâ ch’o ponta in sciù',
    '🫵' => 'dio longâ ch’o ponta à l’osservatô',
    '👍' => 'dio gròsso in sciù',
    '👎' => 'dio gròsso in zu',
    '✊' => 'pugno arsou',
    '👊' => 'pugno ch’o l’arriva',
    '🤛' => 'pugno a-a manciña',
    '🤜' => 'pugno a-a drita',
    '👏' => 'cioccâ de moen',
    '🙌' => 'moen arsæ',
    '🫶' => 'moen à cheu',
    '👐' => 'moen averte',
    '🤲' => 'parmi in sciù assemme',
    '🤝' => 'toccata de man',
    '🙏' => 'moen azzonte',
    '✍' => 'man ch’a scrive',
    '💅' => 'smato pe onge',
    '🤳' => 'selfie',
    '💪' => 'biçipite contræto',
    '🦾' => 'brasso mecanico',
    '🦿' => 'gamba mecanica',
    '🦵' => 'gamba',
    '🦶' => 'pê',
    '👂' => 'oegia',
    '🦻' => 'oegia con appægio pe sentî',
    '👃' => 'naso',
    '🧠' => 'çervello',
    '🫀' => 'cheu anatòmico',
    '🫁' => 'pormoin',
    '🦷' => 'dente',
    '🦴' => 'òsso',
    '👀' => 'euggi',
    '👁' => 'euggio',
    '👅' => 'lengua',
    '👄' => 'bocca',
    '🫦' => 'addentâ o lapro',
    '👶' => 'figgeu da nascion',
    '🧒' => 'figgeu',
    '👦' => 'figgeu masccio',
    '👧' => 'figgeua',
    '🧑' => 'persoña',
    '👱' => 'persoña bionda',
    '👨' => 'òmmo',
    '🧔' => 'persoña co-a barba',
    '👩' => 'dònna',
    '🧓' => 'persoña in etæ',
    '👴' => 'òmmo in etæ',
    '👵' => 'dònna in etæ',
    '🙍' => 'persoña ammagonâ',
    '🙎' => 'persoña inmoronâ',
    '🙅' => 'persoña ch’a fa segno de no',
    '🙆' => 'persoña ch’a fa OK',
    '💁' => 'persoña co-o parmo in sciù',
    '🙋' => 'persoña ch’a tia sciù a man',
    '🧏' => 'persoña sorda',
    '🙇' => 'persoña ch’a fâ scoaccin',
    '🤦' => 'persoña esasperâ',
    '🤷' => 'persoña ch’a strenze e spalle',
    '👮' => 'poliçiòtto',
    '🕵' => 'investigatô',
    '💂' => 'guardia',
    '🥷' => 'ninja',
    '👷' => 'massacan',
    '🫅' => 'persoña co-a coroña',
    '🤴' => 'prinçipe',
    '👸' => 'prinçipessa',
    '👳' => 'persoña co-o turbante',
    '👲' => 'persoña con copolin',
    '🧕' => 'dònna co-o vello',
    '🤵' => 'persoña in smoking',
    '👰' => 'persoña co-o vello',
    '🤰' => 'dònna gräia',
    '🫃' => 'òmmo gräio',
    '🫄' => 'persoña gräia',
    '🤱' => 'dâ o læte',
    '👼' => 'angeo figgeu',
    '🎅' => 'Papà Dënâ',
    '🤶' => 'Mamà Dënâ',
    '🦸' => 'supereröe',
    '🦹' => 'supernemigo',
    '🧙' => 'mago',
    '🧚' => 'foæ',
    '🧛' => 'vampiro',
    '🧜' => 'triton',
    '🧝' => 'elfo',
    '🧞' => 'genio',
    '🧟' => 'zombie',
    '🧌' => 'tròll',
    '💆' => 'persoña ch’a l’é massaggiâ',
    '💇' => 'persoña che ghe taggian i cavelli',
    '🚶' => 'persoña ch’a cammiña',
    '🧍' => 'persoña in pê',
    '🧎' => 'persoña in zenoggion',
    '🏃' => 'persoña ch’a core',
    '💃' => 'dònna ch’a balla',
    '🕺' => 'òmmo ch’o balla',
    '🕴' => 'persoña co-o vestî elegante ch’a levita',
    '👯' => 'persoñe co-e oege da coniggio',
    '🧖' => 'persoña inte unna stansia piña de vapô',
    '🧗' => 'persoña ch’a s’arrampiña',
    '🤺' => 'persoña ch’a tia de spâ',
    '🏇' => 'ippica',
    '⛷' => 'sciatô',
    '🏂' => 'persoña in sciô snowboard',
    '🏌' => 'persoña ch’a zeuga à gòlf',
    '🏄' => 'persoña ch’a fa surf',
    '🚣' => 'persoña ch’a remma',
    '🏊' => 'persoña ch’a neua',
    '⛹' => 'persoña ch’a fa bottezzâ un ballon',
    '🏋' => 'persoña ch’a tia sciù i peixi',
    '🚴' => 'persoña ch’a va in biçicletta',
    '🚵' => 'persoña ch’a va in mountain bike',
    '🤸' => 'persoña ch’a fa a reua',
    '🤼' => 'persoñe che lòttan',
    '🤽' => 'persoña ch’a zeuga à waterpölo',
    '🤾' => 'persoña ch’a zeuga à pallaman',
    '🤹' => 'persoña ch’a fa i zeughi',
    '🧘' => 'persoña in sciâ poxiçion do löto',
    '🛀' => 'persoña ch’a se fâ un bagno',
    '🛌' => 'persoña in letto',
    '👭' => 'doe dònne che se tëgnan pe-a man',
    '👫' => 'dònna e òmmo che se tëgnan pe-a man',
    '👬' => 'doî òmmi che se tëgnan pe-a man',
    '💏' => 'baxo',
    '💑' => 'cobbia con cheucobbia co-o cheu',
    '🗣' => 'testa ch’a parla',
    '👤' => 'profî de busto',
    '👥' => 'profî de doî busti',
    '🫂' => 'persoñe che s’abbrassan',
    '👪' => 'famiggia',
    '👣' => 'impronte de pê',
    '🦰' => 'cavelli rosci',
    '🦱' => 'cavelli arrissoxi',
    '🦳' => 'cavelli gianchi',
    '🦲' => 'peou',
    '🐵' => 'faccia de scimia',
    '🐒' => 'scimia',
    '🦍' => 'gorilla',
    '🦧' => 'rangotan',
    '🐶' => 'moro de can',
    '🐕' => 'can',
    '🦮' => 'can guidda',
    '🐩' => 'can barbin',
    '🐺' => 'lô',
    '🦊' => 'vorpe',
    '🦝' => 'procion',
    '🐱' => 'moro de gatto',
    '🐈' => 'gatto',
    '🦁' => 'lion',
    '🐯' => 'moro de tigre',
    '🐅' => 'tigre',
    '🐆' => 'liopardo',
    '🐴' => 'moro de cavallo',
    '🫎' => 'alce',
    '🫏' => 'ase',
    '🐎' => 'cavallo',
    '🦄' => 'unicòrno',
    '🦓' => 'zebbra',
    '🦌' => 'çervo',
    '🦬' => 'beu sarvægo',
    '🐮' => 'moro de vacca',
    '🐂' => 'beu',
    '🐃' => 'buffao d’ægua',
    '🐄' => 'vacca',
    '🐷' => 'moro de pòrco',
    '🐖' => 'pòrco',
    '🐗' => 'pòrco sarvægo',
    '🐽' => 'naso de pòrco',
    '🐏' => 'æo',
    '🐑' => 'pegoa',
    '🐐' => 'crava',
    '🐪' => 'dromedäio',
    '🐫' => 'cammello',
    '🦙' => 'lamma',
    '🦒' => 'giraffa',
    '🐘' => 'lionfante',
    '🦣' => 'mammut',
    '🦏' => 'rinoçeronte',
    '🦛' => 'ippopòtamo',
    '🐭' => 'moro de rattin',
    '🐁' => 'rattin',
    '🐀' => 'ratto',
    '🐹' => 'criceto',
    '🐰' => 'moro de coniggio',
    '🐇' => 'coniggio',
    '🐿' => 'sciornia',
    '🦫' => 'castöo',
    '🦔' => 'risseu',
    '🦇' => 'rattopennugo',
    '🐻' => 'orso',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'bradipo',
    '🦦' => 'luddria',
    '🦨' => 'gatto spusso',
    '🦘' => 'canguo',
    '🦡' => 'tascio',
    '🐾' => 'impronte de sampe',
    '🦃' => 'bibin',
    '🐔' => 'pollastro',
    '🐓' => 'gallo',
    '🐣' => 'pollin ch’o sciòrte da l’euvo',
    '🐤' => 'pollin',
    '🐥' => 'pollin visto de fronte',
    '🐦' => 'öxello',
    '🐧' => 'pinguin',
    '🕊' => 'comba',
    '🦅' => 'agogia',
    '🦆' => 'ania',
    '🦢' => 'çigno',
    '🦉' => 'dugo',
    '🦤' => 'dödo',
    '🪶' => 'ciumma',
    '🦩' => 'fenicòttero',
    '🦚' => 'pavon',
    '🦜' => 'pappagaggio',
    '🪽' => 'aa',
    '🪿' => 'öca',
    '🐸' => 'ræna',
    '🐊' => 'coccodrillo',
    '🐢' => 'tratugoa',
    '🦎' => 'grigoa',
    '🐍' => 'serpente',
    '🐲' => 'moro de drago',
    '🐉' => 'drago',
    '🦕' => 'sauròpode',
    '🦖' => 'T-Rex',
    '🐳' => 'baleña ch’a broffa l’ægua',
    '🐋' => 'baleña',
    '🐬' => 'drafin',
    '🦭' => 'föca',
    '🐟' => 'pescio',
    '🐠' => 'pescio di tròpichi',
    '🐡' => 'pescio ballon',
    '🦈' => 'squæo',
    '🐙' => 'porpo',
    '🐚' => 'conchiggia',
    '🪸' => 'coalo',
    '🪼' => 'carnassa',
    '🦀' => 'gritta',
    '🦞' => 'ägosta',
    '🦐' => 'gambao',
    '🦑' => 'cämâ',
    '🦪' => 'òstrega',
    '🐌' => 'cägòllo',
    '🦋' => 'parpaggia',
    '🐛' => 'bestieta',
    '🐜' => 'formigoa',
    '🐝' => 'avia',
    '🪲' => 'scarabeo',
    '🐞' => 'dëdê',
    '🦗' => 'grillo',
    '🪳' => 'bagon',
    '🕷' => 'ägno',
    '🕸' => 'tägnâ',
    '🦂' => 'tancoa',
    '🦟' => 'sinsaa',
    '🪰' => 'moscin',
    '🪱' => 'verme',
    '🦠' => 'microbo',
    '💐' => 'masso de scioî',
    '🌸' => 'sciô de çexa',
    '💮' => 'sciô gianca',
    '🪷' => 'sciô de löto',
    '🏵' => 'reusetta',
    '🌹' => 'reusa',
    '🥀' => 'sciô passa',
    '🌺' => 'ibisco',
    '🌻' => 'giäsô',
    '🌼' => 'sciô',
    '🌷' => 'tulipan',
    '🪻' => 'giaçinto',
    '🌱' => 'brutto',
    '🪴' => 'cianta into vaso',
    '🌲' => 'erbo sempreverde',
    '🌳' => 'erbo deçiduo',
    '🌴' => 'parma',
    '🌵' => 'cactus',
    '🌾' => 'spigo de gran',
    '🌿' => 'cianta',
    '☘' => 'treifeuggio',
    '🍀' => 'quaddrifeuggio',
    '🍁' => 'feuggia d’euggiao',
    '🍂' => 'feuggia cheita',
    '🍃' => 'feuggia ch’a xeua a-o vento',
    '🪹' => 'nio veuo',
    '🪺' => 'nio con euve',
    '🍄' => 'fonzo',
    '🍇' => 'uga',
    '🍈' => 'melon',
    '🍉' => 'pateca',
    '🍊' => 'mandarin',
    '🍋' => 'limon',
    '🍌' => 'bananna',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'mei rosso',
    '🍏' => 'mei verde',
    '🍐' => 'pei',
    '🍑' => 'persego',
    '🍒' => 'çexe',
    '🍓' => 'merello',
    '🫐' => 'cornaggin',
    '🥝' => 'kiwi',
    '🍅' => 'tomata',
    '🫒' => 'öiva',
    '🥥' => 'còcco',
    '🥑' => 'avocado',
    '🍆' => 'meizaña',
    '🥔' => 'patatta',
    '🥕' => 'caròttoa',
    '🌽' => 'spigo de granon',
    '🌶' => 'pevionetto',
    '🫑' => 'pevion',
    '🥒' => 'chigheumao',
    '🥬' => 'verdua à feugge verde',
    '🥦' => 'bròccoli',
    '🧄' => 'aggio',
    '🧅' => 'çioula',
    '🥜' => 'pistaccio',
    '🫘' => 'faxeu',
    '🌰' => 'castagna',
    '🫚' => 'raixe de zenzao',
    '🫛' => 'teiga de poïsci',
    '🍞' => 'pan',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'fugassa',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'crêpe',
    '🧇' => 'waffle',
    '🧀' => 'fetta de formaggio',
    '🍖' => 'carne in sce l’òsso',
    '🍗' => 'cheuscia de pollastro',
    '🥩' => 'taggio de carne',
    '🥓' => 'carnesâ',
    '🍔' => 'hamburger',
    '🍟' => 'patatte frite',
    '🍕' => 'pissa',
    '🌭' => 'hot dog',
    '🥪' => 'panetto farçio',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'pita farçia',
    '🧆' => 'falafel',
    '🥚' => 'euvo',
    '🍳' => 'coxinâ',
    '🥘' => 'poela con pittansa',
    '🍲' => 'pugnatta con pittansa',
    '🫕' => 'fondua',
    '🥣' => 'xatta con cuggiâ',
    '🥗' => 'insalatta',
    '🍿' => 'popcòrn',
    '🧈' => 'butiro',
    '🧂' => 'sâ',
    '🥫' => 'mangiâ in scatoa',
    '🍱' => 'bento box',
    '🍘' => 'galetta de riso',
    '🍙' => 'balletta de riso',
    '🍚' => 'riso boggio',
    '🍛' => 'riso co-o curry',
    '🍜' => 'coppetta ch’a fumma',
    '🍝' => 'spaghetti',
    '🍠' => 'patatta doçe rostia',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'gambao frito',
    '🍥' => 'tortin de pescio à spirale',
    '🥮' => 'torta da luña',
    '🍡' => 'dango',
    '🥟' => 'ravieu',
    '🥠' => 'bescheutto da fortuña',
    '🥡' => 'scatoa da portâ via',
    '🍦' => 'gelato inta negia',
    '🍧' => 'granita',
    '🍨' => 'coppa de sciorbetto',
    '🍩' => 'ciambella',
    '🍪' => 'bescheutto',
    '🎂' => 'torta da nataliçio',
    '🍰' => 'fetta de torta',
    '🧁' => 'cupcake',
    '🥧' => 'torta',
    '🍫' => 'bollo de ciccolata',
    '🍬' => 'ciappelletta',
    '🍭' => 'lecca lecca',
    '🍮' => 'bonetto',
    '🍯' => 'arbanella d’amê',
    '🍼' => 'biberon',
    '🥛' => 'gòtto de læte',
    '☕' => 'beviaggio cado',
    '🫖' => 'tiea',
    '🍵' => 'tassa da té sensa manego',
    '🍶' => 'saké',
    '🍾' => 'bottiggia destappâ',
    '🍷' => 'gòtto de vin',
    '🍸' => 'cocktail',
    '🍹' => 'cocktail tropicale',
    '🍺' => 'amoa de bira',
    '🍻' => 'amoe de bira che se toccan',
    '🥂' => 'gòtti che se toccan',
    '🥃' => 'gòtto tumbler',
    '🫗' => 'liquido versou',
    '🥤' => 'gòtto con cannetta',
    '🧋' => 'bubble tea',
    '🧃' => 'beviaggio in scatoa',
    '🧉' => 'mate',
    '🧊' => 'giassa',
    '🥢' => 'bacchette',
    '🍽' => 'forçiña e cotello con tondo',
    '🍴' => 'forçiña e cotello',
    '🥄' => 'cuggiâ',
    '🔪' => 'cotello da coxiña',
    '🫙' => 'arbanella',
    '🏺' => 'giara',
    '🌍' => 'mondo ch’o mostra l’Euröpa e l’Africa',
    '🌎' => 'mondo ch’o mostra e Americhe',
    '🌏' => 'mondo ch’o mostra l’Asia e l’Australia',
    '🌐' => 'glöbo co-i meridien',
    '🗺' => 'carta do mondo',
    '🗾' => 'carta do Giappon',
    '🧭' => 'buscioa',
    '🏔' => 'montagna piña de neive',
    '⛰' => 'montagna',
    '🌋' => 'vurcan',
    '🗻' => 'monte Fuji',
    '🏕' => 'campezzo',
    '🏖' => 'ciazza con päsô',
    '🏜' => 'deserto',
    '🏝' => 'isoa deserta',
    '🏞' => 'parco naçionale',
    '🏟' => 'stadio',
    '🏛' => 'palaçio clascico',
    '🏗' => 'casamento in costruçion',
    '🧱' => 'mon',
    '🪨' => 'scheuggio',
    '🪵' => 'legno',
    '🛖' => 'cabanna',
    '🏘' => 'case',
    '🏚' => 'casa arroinâ',
    '🏠' => 'casa',
    '🏡' => 'casa co-o giardin',
    '🏢' => 'palaçio',
    '🏣' => 'pòste giapponeixi',
    '🏤' => 'pòste',
    '🏥' => 'ospiâ',
    '🏦' => 'banco',
    '🏨' => 'albergo',
    '🏩' => 'love hotel',
    '🏪' => 'minimarket',
    '🏫' => 'scheua',
    '🏬' => 'gran magazzin',
    '🏭' => 'fabrica',
    '🏯' => 'castello giapponeise',
    '🏰' => 'castello',
    '💒' => 'maiezzo',
    '🗼' => 'tore de Tokyo',
    '🗽' => 'statua da Libertæ',
    '⛪' => 'gexa',
    '🕌' => 'moschea',
    '🛕' => 'templio hindu',
    '🕍' => 'scinagöga',
    '⛩' => 'santuäio shintoista',
    '🕋' => 'Kaaba',
    '⛲' => 'fontaña',
    '⛺' => 'tendia',
    '🌁' => 'nëgioso',
    '🌃' => 'neutte co-e stelle',
    '🏙' => 'paisaggio urban',
    '🌄' => 'spægâ do sô in sce montagne',
    '🌅' => 'spægâ do sô',
    '🌆' => 'paisaggio urban a-o tramonto',
    '🌇' => 'tramonto',
    '🌉' => 'ponte de neutte',
    '♨' => 'ægue termale',
    '🎠' => 'cavallo da giòstra',
    '🛝' => 'scuggiæla',
    '🎡' => 'reua panoramica',
    '🎢' => 'montagne rusce',
    '💈' => 'barbê',
    '🎪' => 'tendia do çirco',
    '🚂' => 'locomotiva',
    '🚃' => 'vagon do treno',
    '🚄' => 'treno à erta lestixe',
    '🚅' => 'tren à ertiscima lestixe',
    '🚆' => 'treno',
    '🚇' => 'metropolitaña',
    '🚈' => 'treno legio',
    '🚉' => 'staçion',
    '🚊' => 'tranväi',
    '🚝' => 'monorail',
    '🚞' => 'treno de montagna',
    '🚋' => 'vagon de tranväi',
    '🚌' => 'autobus',
    '🚍' => 'autobus ch’o l’arriva',
    '🚎' => 'filobus',
    '🚐' => 'minibus',
    '🚑' => 'ambulansa',
    '🚒' => 'camio di pompê',
    '🚓' => 'machina da poliscia',
    '🚔' => 'machina da poliscia ch’a l’arriva',
    '🚕' => 'tascì',
    '🚖' => 'tascì ch’o l’arriva',
    '🚗' => 'machina',
    '🚘' => 'machina ch’a l’arriva',
    '🚙' => 'SUV',
    '🛻' => 'pickup',
    '🚚' => 'camio',
    '🚛' => 'camio articolou',
    '🚜' => 'trattô',
    '🏎' => 'machina da corsa',
    '🏍' => 'möto',
    '🛵' => 'motoretta',
    '🦽' => 'carrega à roete',
    '🦼' => 'carrega à roete à motô',
    '🛺' => 'risciò à motô',
    '🚲' => 'biçicletta',
    '🛴' => 'monopattino',
    '🛹' => 'skateboard',
    '🛼' => 'pattin à roete',
    '🚏' => 'fermâ de l’autobus',
    '🛣' => 'autostrâ',
    '🛤' => 'colisse do treno',
    '🛢' => 'barî de petròlio',
    '⛽' => 'pompa de benziña',
    '🛞' => 'reua',
    '🚨' => 'lampezzante da poliscia',
    '🚥' => 'semaforo orizzontale',
    '🚦' => 'semaforo verticale',
    '🛑' => 'segnâ de stòp',
    '🚧' => 'cantê',
    '⚓' => 'ancoa',
    '🛟' => 'sarvagente',
    '⛵' => 'barca à veia',
    '🛶' => 'canöa',
    '🚤' => 'motoscafo',
    '🛳' => 'barco da croxea',
    '⛴' => 'barco da passaggê',
    '🛥' => 'barca à motô',
    '🚢' => 'barco',
    '✈' => 'aereo',
    '🛩' => 'aereo piccin',
    '🛫' => 'aereo ch’o parte',
    '🛬' => 'aereo ch’o l’arriva',
    '🪂' => 'paracadute',
    '💺' => 'setto',
    '🚁' => 'elicòttero',
    '🚟' => 'ferrovia sospeisa',
    '🚠' => 'funivia',
    '🚡' => 'tranväi aereo',
    '🛰' => 'satellite',
    '🚀' => 'miscile',
    '🛸' => 'UFO',
    '🛎' => 'campanetta da albergo',
    '🧳' => 'valixe',
    '⌛' => 'releuio d’æña fermo',
    '⏳' => 'releuio d’æña ch’o core',
    '⌚' => 'releuio',
    '⏰' => 'resveggin',
    '⏱' => 'cronòmetro',
    '⏲' => 'timer',
    '🕰' => 'releuio da modiggion',
    '🕛' => 'dozz’oe',
    '🕧' => 'dozze e meza',
    '🕐' => 'unn’oa',
    '🕜' => 'uña e meza',
    '🕑' => 'doe oe',
    '🕝' => 'doe e meza',
    '🕒' => 'træ oe',
    '🕞' => 'træ e meza',
    '🕓' => 'quattr’oe',
    '🕟' => 'quattro e meza',
    '🕔' => 'çinqu’oe',
    '🕠' => 'çinque e meza',
    '🕕' => 'sëi oe',
    '🕡' => 'sëi e meza',
    '🕖' => 'sett’oe',
    '🕢' => 'sette e meza',
    '🕗' => 'eutt’oe',
    '🕣' => 'eutto e meza',
    '🕘' => 'neuv’oe',
    '🕤' => 'neuve e meza',
    '🕙' => 'dex’oe',
    '🕥' => 'dexe e meza',
    '🕚' => 'unz’oe',
    '🕦' => 'unze e meza',
    '🌑' => 'luña neuva',
    '🌒' => 'luña ch’a cresce',
    '🌓' => 'luña a-o primmo quarto',
    '🌔' => 'luña gibbosa ch’a cresce',
    '🌕' => 'luña piña',
    '🌖' => 'luña gibbosa ch’a caa',
    '🌗' => 'luña à l’urtimo quarto',
    '🌘' => 'luña ch’a caa',
    '🌙' => 'mëzaluña',
    '🌚' => 'morin de luña neuva',
    '🌛' => 'morin de luña a-o primmo quarto',
    '🌜' => 'morin de luña à l’urtimo quarto',
    '🌡' => 'termòmetro',
    '☀' => 'sô',
    '🌝' => 'morin de luña piña',
    '🌞' => 'morin de sô',
    '🪐' => 'pianeta con l’anello',
    '⭐' => 'stella',
    '🌟' => 'stella ch’a luxe',
    '🌠' => 'stella cadente',
    '🌌' => 'via lattea',
    '☁' => 'nuvia',
    '⛅' => 'sô derê à unna nuvia',
    '⛈' => 'nuvia co-o lampo e l’ægua',
    '🌤' => 'sô derê à unna nuva picciña',
    '🌥' => 'sô derê à unna nuvia grande',
    '🌦' => 'sô derê à unna nuvia con l’ægua',
    '🌧' => 'nuvia con l’ægua',
    '🌨' => 'nuvia co-a neive',
    '🌩' => 'nuvia co-o lampo',
    '🌪' => 'dragoña',
    '🌫' => 'negia',
    '🌬' => 'faccia ch’a sciuscia',
    '🌀' => 'çiclon',
    '🌈' => 'archinçê',
    '🌂' => 'pægua serrou',
    '☂' => 'pægua',
    '☔' => 'pægua con stisse d’ægua',
    '⛱' => 'päsô',
    '⚡' => 'erta tenscion',
    '❄' => 'strasso de neive',
    '☃' => 'òmmo de neive',
    '⛄' => 'òmmo de neive sensa neive',
    '☄' => 'stella cometa',
    '🔥' => 'feugo',
    '💧' => 'stissa',
    '🌊' => 'onda',
    '🎃' => 'succa de Halloween',
    '🎄' => 'erbo de Dënâ',
    '🎆' => 'furgao',
    '🎇' => 'stelliñe schillente',
    '🧨' => 'petardo',
    '✨' => 'zimme',
    '🎈' => 'ballonetto',
    '🎉' => 'coriandoli',
    '🎊' => 'balla de coriandoli',
    '🎋' => 'erbo de Tanabata',
    '🎍' => 'bambù addobbou',
    '🎎' => 'bugatte giapponeixi',
    '🎏' => 'bandea à carpa',
    '🎐' => 'campaña a-o vento',
    '🎑' => 'çeimònia de contemplaçion da luña',
    '🧧' => 'anvelòppe hongbao',
    '🎀' => 'frexetto',
    '🎁' => 'regallo fasciou',
    '🎗' => 'frexetto pe-a memöia',
    '🎟' => 'biggetti d’intrâ',
    '🎫' => 'biggetto',
    '🎖' => 'medaggia militare',
    '🏆' => 'coppa',
    '🏅' => 'medaggia sportiva',
    '🥇' => 'medaggia d’öo',
    '🥈' => 'medaggia d’argento',
    '🥉' => 'medaggia de bronzo',
    '⚽' => 'ballon',
    '⚾' => 'ballon da baseball',
    '🥎' => 'ballon da softball',
    '🏀' => 'ballon da basket',
    '🏐' => 'ballon da volley',
    '🏈' => 'ballon da football american',
    '🏉' => 'ballon da rugby',
    '🎾' => 'balletta da tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'hockey in sce prou',
    '🏒' => 'hockey in sce giassa',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pòng',
    '🏸' => 'ciummin',
    '🥊' => 'guante da boxe',
    '🥋' => 'kimono pe arte marçiale',
    '🥅' => 'pòrta da ballon',
    '⛳' => 'beuggio do gòlf',
    '⛸' => 'pattin da giassa',
    '🎣' => 'çimmello',
    '🤿' => 'mascara da magron',
    '🎽' => 'canottea da corrî',
    '🎿' => 'scî',
    '🛷' => 'leza',
    '🥌' => 'pria da curling',
    '🎯' => 'çibbla',
    '🪀' => 'yo-yo',
    '🪁' => 'cometa',
    '🔫' => 'pistòlla à ægua',
    '🎱' => 'bilia 8 do biliardo',
    '🔮' => 'sfera de crestallo',
    '🪄' => 'bacchetta magica',
    '🎮' => 'videozeugo',
    '🕹' => 'joystick',
    '🎰' => 'slot machine',
    '🎲' => 'dæ',
    '🧩' => 'pesso de puzzle',
    '🧸' => 'orsettin',
    '🪅' => 'pugnatta',
    '🪩' => 'balla da discoteca',
    '🪆' => 'matrioska',
    '♠' => 'mersa de spoæ',
    '♥' => 'mersa de coppe',
    '♦' => 'mersa de dinæ',
    '♣' => 'mersa de scioî',
    '♟' => 'pediña di scacchi',
    '🃏' => 'joker',
    '🀄' => 'pesso do Mahjong',
    '🎴' => 'carta Hanafuda',
    '🎭' => 'mascare do tiatro',
    '🖼' => 'quaddro incornixou',
    '🎨' => 'töeta da pittô',
    '🧵' => 'fî',
    '🪡' => 'agoggia',
    '🧶' => 'remescello de fî',
    '🪢' => 'groppo',
    '👓' => 'speggetti',
    '🕶' => 'speggetti neigri',
    '🥽' => 'mascara',
    '🥼' => 'camixo',
    '🦺' => 'gipponetto de seguessa',
    '👔' => 'crovata',
    '👕' => 'maggetta',
    '👖' => 'jeans',
    '🧣' => 'scerpa',
    '🧤' => 'guanti',
    '🧥' => 'cappòtto',
    '🧦' => 'scappin',
    '👗' => 'röba',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'costumme da bagno intrego',
    '🩲' => 'miande',
    '🩳' => 'braghe curte',
    '👙' => 'bikini',
    '👚' => 'vestî da dònna',
    '🪭' => 'bandeta',
    '👛' => 'portamonæa',
    '👜' => 'borsa',
    '👝' => 'pochette',
    '🛍' => 'borse da speisa',
    '🎒' => 'saino',
    '🩴' => 'sandola',
    '👞' => 'scarpa da òmmo',
    '👟' => 'scarpa da corrî',
    '🥾' => 'treuxo',
    '🥿' => 'scarpa da ballæña',
    '👠' => 'scarpa co-o tacco',
    '👡' => 'sandola da dònna',
    '🩰' => 'scarpe da balletto',
    '👢' => 'stivâ da dònna',
    '🪮' => 'petene afro',
    '👑' => 'coroña',
    '👒' => 'cappello da dònna',
    '🎩' => 'çilindro',
    '🎓' => 'cappello da dottô',
    '🧢' => 'cappellin co-a padelletta',
    '🪖' => 'elmo da sordatto',
    '⛑' => 'elmo con croxe gianca',
    '📿' => 'rosäio',
    '💄' => 'roscetto',
    '💍' => 'anello',
    '💎' => 'gemma',
    '🔇' => 'altoparlante feua d’in fonçion',
    '🔈' => 'altoparlante à volumme basso',
    '🔉' => 'altoparlante à volumme medio',
    '🔊' => 'altoparlante à volumme erto',
    '📢' => 'altoparlante',
    '📣' => 'megafono',
    '📯' => 'còrno da pòsta',
    '🔔' => 'campaña',
    '🔕' => 'campaña barrâ',
    '🎼' => 'pentagramma',
    '🎵' => 'nòtta muxicale',
    '🎶' => 'nòtte muxicale',
    '🎙' => 'micròfono de l’aradio',
    '🎚' => 'levetta do volumme',
    '🎛' => 'pommelli de contròllo',
    '🎤' => 'micròfono',
    '🎧' => 'scuffie',
    '📻' => 'aradio',
    '🎷' => 'sasciòfono',
    '🎺' => 'tromba',
    '🪗' => 'fisa',
    '🎸' => 'chitara',
    '🎹' => 'piano',
    '🎻' => 'violin',
    '🪕' => 'banjo',
    '🥁' => 'tambuo',
    '🪘' => 'tambuo longo',
    '🪇' => 'maracas',
    '🪈' => 'flauto',
    '📱' => 'telefonin',
    '📲' => 'telefonin con freccia',
    '☎' => 'telefono',
    '📞' => 'cornetta do telefono',
    '📟' => 'çercapersoñe',
    '📠' => 'fax',
    '🔋' => 'batteria',
    '🪫' => 'batteria descarrega',
    '🔌' => 'preisa de l’elettriçitæ',
    '💻' => 'laptop',
    '🖥' => 'computer fisso',
    '🖨' => 'stampante',
    '⌨' => 'tastea',
    '🖱' => 'mouse',
    '🖲' => 'trackball',
    '💽' => 'minidisc',
    '💾' => 'floppy disk',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'abachin',
    '🎥' => 'cinepreisa',
    '🎞' => 'pellicola da cine',
    '📽' => 'proiettô',
    '🎬' => 'ciak',
    '📺' => 'televixon',
    '📷' => 'machina fotografica',
    '📸' => 'machina fotografica con flash',
    '📹' => 'videocamera',
    '📼' => 'videocascetta',
    '🔍' => 'lente a-a manciña',
    '🔎' => 'lente a-a drita',
    '🕯' => 'candeia',
    '💡' => 'lampadiña',
    '🔦' => 'tòrcia',
    '🏮' => 'lanterna de papê rosso',
    '🪔' => 'diya',
    '📔' => 'querno con covertiña decorâ',
    '📕' => 'libbro serrou',
    '📖' => 'libbro averto',
    '📗' => 'libbro verde',
    '📘' => 'libbro bleu',
    '📙' => 'libbro cô de çetron',
    '📚' => 'libbri',
    '📓' => 'querno',
    '📒' => 'querno à anelli',
    '📃' => 'pagina arrissâ',
    '📜' => 'pergamena',
    '📄' => 'pagina',
    '📰' => 'giornale',
    '🗞' => 'giornale abbigoelou',
    '📑' => 'marcapagina',
    '🔖' => 'segnalibbro',
    '🏷' => 'etichetta',
    '🪙' => 'monæa',
    '💰' => 'sacco de dinæ',
    '💴' => 'biggetto Yen',
    '💵' => 'biggetto Dòllao',
    '💶' => 'biggetto Euro',
    '💷' => 'biggetto Sterliña',
    '💸' => 'biggetto de banca con ae',
    '💳' => 'carta de credito',
    '🧾' => 'fattua',
    '💹' => 'grafico con Yen ch’o monta',
    '✉' => 'anvelòppe',
    '📧' => 'pòsta elettrònica',
    '📨' => 'anvelòppe ch’a l’arriva',
    '📩' => 'anvelòppe con freccia',
    '📤' => 'pòsta ch’a sciòrte',
    '📥' => 'pòsta ch’a l’arriva',
    '📦' => 'pacco',
    '📫' => 'cascetta da pòsta serrâ con bandea tiâ sciù',
    '📪' => 'cascetta da pòsta serrâ con bandea tiâ zu',
    '📬' => 'cascetta da pòsta averta con bandea tiâ sciù',
    '📭' => 'cascetta da pòsta averta con bandea tiâ zu',
    '📮' => 'cascetta da pòsta',
    '🗳' => 'urna de votaçion',
    '✏' => 'lapi',
    '✒' => 'pennin neigro',
    '🖋' => 'penna stilografica',
    '🖊' => 'penna',
    '🖌' => 'pennello',
    '🖍' => 'pastello à çeia',
    '📝' => 'arregòrdo',
    '💼' => 'valixetta',
    '📁' => 'cartella pe documenti',
    '📂' => 'cartella pe documenti averta',
    '🗂' => 'etichette pe schedäio',
    '📅' => 'lunäio',
    '📆' => 'lunäio da sguarâ',
    '🗒' => 'querno à spirale',
    '🗓' => 'lunäio à spirale',
    '📇' => 'schedäio',
    '📈' => 'grafico ch’o monta',
    '📉' => 'grafico ch’o chiña',
    '📊' => 'grafico à barre',
    '📋' => 'toëta con papê',
    '📌' => 'pontiña',
    '📍' => 'pontaieu',
    '📎' => 'graffetta',
    '🖇' => 'graffette incroxæ',
    '📏' => 'riga',
    '📐' => 'squaddra',
    '✂' => 'tesoie',
    '🗃' => 'schedäio da töa',
    '🗄' => 'schedäio da scagno',
    '🗑' => 'çestin',
    '🔒' => 'lucchetto serrou',
    '🔓' => 'lucchetto averto',
    '🔏' => 'lucchetto serrou con penna',
    '🔐' => 'lucchetto serrou con ciave',
    '🔑' => 'ciave',
    '🗝' => 'ciave vegia',
    '🔨' => 'martello',
    '🪓' => 'ascia',
    '⛏' => 'picco',
    '⚒' => 'martello e picco',
    '🛠' => 'martello e ciave ingleise',
    '🗡' => 'pugnâ',
    '⚔' => 'spoæ incroxæ',
    '💣' => 'bomboa',
    '🪃' => 'boomerang',
    '🏹' => 'erco e freccia',
    '🛡' => 'scuo',
    '🪚' => 'særa',
    '🔧' => 'ciave ingleise',
    '🪛' => 'cacciavie',
    '🔩' => 'bollon e daddo',
    '⚙' => 'ingranaggio',
    '🗜' => 'mòrsa',
    '⚖' => 'bansa',
    '🦯' => 'bacco da òrbi',
    '🔗' => 'ligammo',
    '⛓' => 'cadeñe',
    '🪝' => 'gancio',
    '🧰' => 'cascetta di færi',
    '🧲' => 'calamitta',
    '🪜' => 'scâ',
    '⚗' => 'lambicco',
    '🧪' => 'provetta',
    '🧫' => 'tondo de Petri',
    '🧬' => 'DNA',
    '🔬' => 'microscòpio',
    '🔭' => 'telescòpio',
    '📡' => 'antennia satellitare',
    '💉' => 'sciringa',
    '🩸' => 'stissa de sangue',
    '💊' => 'pilloa',
    '🩹' => 'çiöto',
    '🩼' => 'scròssoa',
    '🩺' => 'stetoscòpio',
    '🩻' => 'raggi X',
    '🚪' => 'pòrta',
    '🛗' => 'ascensô',
    '🪞' => 'spegio',
    '🪟' => 'barcon',
    '🛏' => 'letto',
    '🛋' => 'canapê e lampa',
    '🪑' => 'carrega',
    '🚽' => 'leugo',
    '🪠' => 'destappalavelli',
    '🚿' => 'doccia',
    '🛁' => 'vasca da bagno',
    '🪤' => 'rattaieu',
    '🪒' => 'rasô',
    '🧴' => 'bottiggia de loçion',
    '🧷' => 'spillon',
    '🧹' => 'spassoia',
    '🧺' => 'còrba',
    '🧻' => 'rolò de papê',
    '🪣' => 'bollacco',
    '🧼' => 'savon',
    '🫧' => 'ampolle',
    '🪥' => 'spassetta da denti',
    '🧽' => 'sponzia',
    '🧯' => 'estintô',
    '🛒' => 'carretto da speisa',
    '🚬' => 'çigaretta',
    '⚰' => 'cascia da mòrto',
    '🪦' => 'tomba',
    '⚱' => 'urna funeräia',
    '🧿' => 'euggio de Allah',
    '🪬' => 'man de Fatima',
    '🗿' => 'Moai',
    '🪧' => 'cartello',
    '🪪' => 'carta d’identitæ',
    '🏧' => 'bancomat',
    '🚮' => 'bollacco da rumenta',
    '🚰' => 'ægua potabile',
    '♿' => 'scimbolo de carrega à roete',
    '🚹' => 'leugo pe òmmi',
    '🚺' => 'leugo pe dònne',
    '🚻' => 'stançia da bagno',
    '🚼' => 'scimbolo de figgeu da nascion',
    '🚾' => 'scimbolo de leugo',
    '🛂' => 'contròllo di passapòrti',
    '🛃' => 'dugaña',
    '🛄' => 'retio de valixe',
    '🛅' => 'depöxito de valixe',
    '⚠' => 'avviso',
    '🚸' => 'figgeu che attraversan',
    '⛔' => 'intrâ proibia',
    '🚫' => 'proibio',
    '🚳' => 'biçiclette proibie',
    '🚭' => 'fumme proibio',
    '🚯' => 'proibiçion de cacciâ via a rumenta',
    '🚱' => 'ægua no potabile',
    '🚷' => 'proibio a-i pedoin',
    '📵' => 'telefonin proibii',
    '🔞' => 'proibio a-i minoî de 18 anni',
    '☢' => 'radioattivo',
    '☣' => 'peigo biològico',
    '⬆' => 'freccia in sciù',
    '↗' => 'freccia in sciù a-a drita',
    '➡' => 'freccia a-a drita',
    '↘' => 'freccia in zu a-a drita',
    '⬇' => 'freccia in zu',
    '⬅' => 'freccia a-a manciña',
    '↖' => 'freccia in sciù a-a manciña',
    '↕' => 'freccia in sciù e in zu',
    '↔' => 'freccia a-a drita e a-a manciña',
    '↩' => 'freccia curva a-a manciña',
    '↪' => 'freccia curva a-a drita',
    '⤴' => 'freccia curva in sciù',
    '⤵' => 'freccia curva in zu',
    '🔃' => 'frecce into senso de ragge do releuio',
    '🔄' => 'frecce into senso conträio a-e ragge',
    '🔙' => 'freccia BACK',
    '🔚' => 'freccia END',
    '🔛' => 'freccia ON!',
    '🔜' => 'freccia SOON',
    '🔝' => 'freccia TOP',
    '🛐' => 'pòsto de adoraçion',
    '⚛' => 'scimbolo de l’atomo',
    '🕉' => 'om',
    '✡' => 'stella de David',
    '☸' => 'reua do Dharma',
    '☯' => 'ying yang',
    '✝' => 'croxe latiña',
    '☦' => 'croxe ortodòssa',
    '☪' => 'mëzaluña e stella',
    '☮' => 'scimbolo da paxe',
    '🕎' => 'Menorah',
    '🔯' => 'stella de David co-o pontin',
    '🪯' => 'khanda',
    '♈' => 'æo do zodiaco',
    '♉' => 'töo do zodiaco',
    '♊' => 'binelli do zodiaco',
    '♋' => 'gritta do zodiaco',
    '♌' => 'lion do zodiaco',
    '♍' => 'vergine do zodiaco',
    '♎' => 'bansa do zodiaco',
    '♏' => 'tancoa do zodiaco',
    '♐' => 'arçê do zodiaco',
    '♑' => 'cravicòrno do zodiaco',
    '♒' => 'versou do zodiaco',
    '♓' => 'pesci do zodiaco',
    '⛎' => 'ofiuco do zodiaco',
    '🔀' => 'pommello de reproduçion aleatöia',
    '🔁' => 'pommello de repetiçion da reproduçion',
    '🔂' => 'pommello de repetiçion de unna traccia',
    '▶' => 'pommello de reproduçion',
    '⏩' => 'pommello avanti lesto',
    '⏭' => 'pommello pròscima traccia',
    '⏯' => 'pommello reproduxi ò pösa',
    '◀' => 'pommello retorno',
    '⏪' => 'pommello retorno lesto',
    '⏮' => 'pommello traccia passâ',
    '🔼' => 'pommello sciù',
    '⏫' => 'pommello sciù lesto',
    '🔽' => 'pommello zu',
    '⏬' => 'pommello zu lesto',
    '⏸' => 'pommello pösa',
    '⏹' => 'pommello stòp',
    '⏺' => 'pommello registraçion',
    '⏏' => 'pommello manda feua',
    '🎦' => 'cine',
    '🔅' => 'pommello luminoxitæ bassa',
    '🔆' => 'pommello luminoxitæ erta',
    '📶' => 'barre de l’antennia',
    '🛜' => 'Wi-Fi',
    '📳' => 'fonçion de vibraçion',
    '📴' => 'telefonin asmòrto',
    '♀' => 'scimbolo da femmina',
    '♂' => 'scimbolo de l’òmmo',
    '⚧' => 'scimbolo transgender',
    '✖' => 'moltiplicaçion',
    '➕' => 'addiçion',
    '➖' => 'sottraçion',
    '➗' => 'divixon',
    '🟰' => 'scimbolo de egualiansa',
    '♾' => 'infinio',
    '‼' => 'ponto d’esclamaçion doggio',
    '⁉' => 'ponto d’esclamaçion e d’interrogaçion',
    '❓' => 'ponto d’interrogaçion rosso',
    '❔' => 'ponto d’interrogaçion gianco',
    '❕' => 'ponto d’esclamaçion gianco',
    '❗' => 'ponto d’esclamaçion rosso',
    '〰' => 'træto ondezzou',
    '💱' => 'bancouto',
    '💲' => 'scimbolo do dòllao',
    '⚕' => 'scimbolo da mëxiña',
    '♻' => 'scimbolo do reçiclo',
    '⚜' => 'livio araldico',
    '🔱' => 'scimbolo do tridente',
    '📛' => 'etichetta pe-o nomme',
    '🔰' => 'scimbolo giapponeise “prinçipiante”',
    '⭕' => 'çercio rosso veuo',
    '✅' => 'pommello marca de seleçion',
    '☑' => 'quaddro con marca de seleçion',
    '✔' => 'marca de seleçion',
    '❌' => 'marca da croxe',
    '❎' => 'pommello marca da croxe',
    '➰' => 'gassetta',
    '➿' => 'gassetta doggia',
    '〽' => 'scimbolo d’alternansa de parte',
    '✳' => 'asterisco à eutto ponte',
    '✴' => 'stella à eutto ponte',
    '❇' => 'scimbolo da zimma',
    '™' => 'marca registrâ',
    '🔠' => 'pommello con lettie latiñe gròsse',
    '🔡' => 'pommello con lettie latiñe picciñe',
    '🔢' => 'pommello con giffre',
    '🔣' => 'pommello con scimboli',
    '🔤' => 'pommello con lettie latiñe',
    '🅰' => 'pomello do gruppo de sangue A',
    '🆎' => 'pomello do gruppo de sangue AB',
    '🅱' => 'pomello do gruppo de sangue B',
    '🆑' => 'pommello CL',
    '🆒' => 'pommello COOL',
    '🆓' => 'pommello FREE',
    'ℹ' => 'informaçioin',
    '🆔' => 'pommello ID',
    'Ⓜ' => 'M çerciâ',
    '🆕' => 'pommello NEW',
    '🆖' => 'pommello NG',
    '🅾' => 'pomello do gruppo de sangue O',
    '🆗' => 'pommello OK',
    '🅿' => 'pommello P',
    '🆘' => 'pommello SOS',
    '🆙' => 'pommello UP!',
    '🆚' => 'pommello VS',
    '🈁' => 'pommello giapponeise “chì”',
    '🈂' => 'pommello giapponeise “costo do servixo”',
    '🈷' => 'pommello giapponeise “totale a-o meise”',
    '🈶' => 'pommello giapponeise “no de badda”',
    '🈯' => 'pommello giapponeise “reservou”',
    '🉐' => 'pommello giapponeise “occaxon”',
    '🈹' => 'pommello giapponeise “rebasso”',
    '🈚' => 'pommello giapponeise “de badda”',
    '🈲' => 'pommello giapponeise “proibio”',
    '🉑' => 'pommello giapponeise “andante”',
    '🈸' => 'pommello giapponeise “candidatua”',
    '🈴' => 'pommello giapponeise “bastante”',
    '🈳' => 'pommello giapponeise “pòsti veui”',
    '㊗' => 'pommello giapponeise “feliçitaçioin”',
    '㊙' => 'pommello giapponeise “segretto”',
    '🈺' => 'pommello giapponeise “averto”',
    '🈵' => 'pommello giapponeise “pòsti occupæ”',
    '🔴' => 'çercio rosso',
    '🟠' => 'çercio cô de çetron',
    '🟡' => 'çercio giano',
    '🟢' => 'çercio verde',
    '🔵' => 'çercio bleu',
    '🟣' => 'çercio moelo',
    '🟤' => 'çercio marròn',
    '⚫' => 'çercio neigro',
    '⚪' => 'çercio gianco',
    '🟥' => 'quaddro rosso',
    '🟧' => 'quaddro cô de çetron',
    '🟨' => 'quaddro giano',
    '🟩' => 'quaddro verde',
    '🟦' => 'quaddro bleu',
    '🟪' => 'quaddro moelo',
    '🟫' => 'quaddro marròn',
    '⬛' => 'quaddro neigro gròsso',
    '⬜' => 'quaddro gianco gròsso',
    '◼' => 'quaddro medio neigro',
    '◾' => 'quaddro neigro medio',
    '▪' => 'quaddro piccin neigro',
    '▫' => 'quaddro piccin gianco',
    '🔶' => 'rombo cô de çetron gròsso',
    '🔷' => 'rombo bleu gròsso',
    '🔸' => 'rombo cô de çetron piccin',
    '🔹' => 'rombo bleu piccin',
    '🔺' => 'triangolo rosso co-a ponta in sciù',
    '🔻' => 'triangolo rosso co-a ponta in zu',
    '💠' => 'diamante co-o ponto',
    '🔘' => 'pommello de l’aradio',
    '🔳' => 'pommello con quaddro gianco',
    '🔲' => 'pommello con quaddro neigro',
    '🏁' => 'bandea quaddriggiâ',
    '🚩' => 'bandea triangolare',
    '🎌' => 'bandee incroxæ',
    '🏴' => 'bandea neigra',
    '🏳' => 'bandea gianca',
];
